#delimit ;

log using do\calccs01,replace;

*************************************************************;
*                                                           *;
*    Name    : CALCCS01.DO              V : 01              *;
*    Date    : JULY 26,1994                                 *;
*    Infile  : FOODQC02, HHSIZE                             *;
*    Outfile : HHCAL                                        *;
*                                                           *;
*    OBJECTIVE: calculate per capita daily calories         *;
*               calculate calories for group commodities    *;
*               get total calories and calorie shares       *;
*                                                           *;
*************************************************************;
set more 1;
set maxobs 153000;

use foodqc02;

des;

keep hhid foodcode daycal;
sort hhid;

**  Calculate per capita household calories using file hhsize   **
**  and the variable hhsizem which includes all members  in     **
**  the household                                               **   
;
merge hhid using hhsize;
tab _merge;
drop _merge;

gen pccal=daycal/hhsizem;

drop daycal hhsizep;

sort hhid;

save step00,replace;

*  Calculate the variables for the first part  ;
egen ptcgrain=sum(pccal)
               if foodcode>=1 & foodcode<=6 ,by(hhid);
egen ptcmeafi=sum(pccal)
               if foodcode>=18 & foodcode<=22 ,by(hhid);
collapse 
     hhsizem ptcgrain ptcmeafi, 
     by(hhid)
     max(hhsizem ptcgrain ptcmeafi);

sort hhid;

save step01,replace;

*  Calculate the variables for the second part  ;
use step00;

egen ptcdairy=sum(pccal)
               if foodcode==13 | foodcode>=15 & foodcode<=16 ,by(hhid);
egen ptcfruve=sum(pccal)
               if foodcode>=7 & foodcode<=10 |
                  foodcode>=23 & foodcode<=27  ,by(hhid);
collapse 
     ptcdairy ptcfruve, by(hhid)
     max(ptcdairy ptcfruve);

sort hhid;

save step02,replace;

*  Calculate the varialbes for the third part ;
use step00;

egen ptcoils =sum(pccal)
               if foodcode>=11 & foodcode<=12  ,by(hhid);
egen ptcsugar=sum(pccal)
               if foodcode==17 ,by(hhid);
collapse 
     ptcoils ptcsugar, by(hhid)
     max(ptcoils ptcsugar);

sort hhid;

save step03,replace;

*  Calculate the varialbes for the fourth part ;
use step00;

egen ptcother=sum(pccal)
               if foodcode==14 | foodcode==28  ,by(hhid);
egen pctcal=sum(pccal), by(hhid);

collapse 
     ptcother pctcal, by(hhid)
     max(ptcother pctcal);

sort hhid;

save step04,replace;

!del step00.dta;

*  Merge all the parts togehter ;

clear;

set maxobs 10000;

use step01;

merge hhid using step02;
drop _merge;
sort hhid;

merge hhid using step03;
drop _merge;
sort hhid;

merge hhid using step04;
drop _merge;
sort hhid;

lab data "Per capita calories";
lab var ptcgrain "Per capita grain calories";
lab var ptcmeafi "Per capita meat & fish calories";
lab var ptcdairy "Per capita dairy calories";
lab var ptcfruve "Per capita fru. and veg. calories";
lab var ptcoils "Per capita oil calories";
lab var ptcsugar "Per capita sugar calories";
lab var ptcother "Per capita other calories";
lab var pctcal "Per capita total daily calories";

**  Check if the total Calories derived from the two mathods **;
**  give the save results                                    **;

egen pctot=rsum(ptc*);
sum pctot pctcal;
drop pctot;

sort hhid;

***  Generate calorie shares. Include only the households that  **;
***  have at least some total calories                          **;

gen scgrain = 100*ptcgrain/pctcal;
gen scmeafi = 100*ptcmeafi/pctcal;
gen scdairy = 100*ptcdairy/pctcal;
gen scfruve = 100*ptcfruve/pctcal;
gen scoils  = 100*ptcoils/pctcal;
gen scsugar = 100*ptcsugar/pctcal;
gen scother = 100*ptcother/pctcal;

replace scgrain = 0 if scgrain ==. & pctcal>0;
replace scmeafi = 0 if scmeafi ==. & pctcal>0;
replace scdairy = 0 if scdairy ==. & pctcal>0;
replace scfruve = 0 if scfruve ==. & pctcal>0;
replace scoils  = 0 if scoils  ==. & pctcal>0;
replace scsugar = 0 if scsugar ==. & pctcal>0;
replace scother = 0 if scother ==. & pctcal>0;

lab var scgrain "Share grain calories";
lab var scmeafi "Share meat & fish calories";
lab var scdairy "Share dairy calories";
lab var scfruve "Share fru. and veg. calories";
lab var scoils  "Share oil calories";
lab var scsugar "Share sugar calories";
lab var scother "Share other calories";

save hhcal,replace;

!del step01.dta;
!del step02.dta;
!del step03.dta;
!del step04.dta;

des;
sum;

sum pctcal, det;

count if pctcal>7000;

log close;
