#delimit ;

log using do\calcnf1x,replace;
set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CALCNF1X.DO              V : 01              *;
*    Date    : JULY 7, 1994                                 *;
*    Infile  : M2_NFS1                                      *;
*    Outfile : NF1X01                                       *;
*                                                           *;
*    OBJECTIVE: Calculate the values of expenditure for     *;
*               each of the non food commodities            *;
*                                                           *;
*************************************************************;
set more 1;

clear;
set maxobs 45000;
use m2_nfs1;
des;
sum;

***  CHECK THE MISSING OF THE NON FOOD REGULAR EXPENDITURES  **;

gen flag=1 if rnfs_a<0;
replace rnfs_a=. if flag==1;
tab rnfs_c, sum(flag);
save step00,replace;

use s4_hdef;
keep hhid;
sort hhid;
lab data "Non Food Regular: Mon Expenditure";
save nf1x01,replace;

*_NOTE: There are several true missing (Do not Know and refusals) values 
        which are set to missing.  Non reporting exenditure is set to 
        zero.  There are in total approximately 64 households that do not
        report any expenditure: they are set to zero
;

** CALCULATE THE INDIVIDUAL EXPENDITURE VARIABLES         **
;
** comm01;
use step00;
drop if rnfs_c~=1;
collapse rnfs_a flag, by(hhid) sum(mxcig f1);
recast float mxcig;
lab var mxcig "Cigarettes and Tobacco Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxcig=0 if mxcig==.;
replace mxcig=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;


** comm02;
use step00;
drop if rnfs_c~=2;
collapse rnfs_a flag, by(hhid) sum(mxalc f1);
recast float mxalc;
lab var mxalc "Spirits Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxalc=0 if mxalc==.;
replace mxalc=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;

** comm03;
use step00;
drop if rnfs_c~=3;
collapse rnfs_a flag, by(hhid) sum(mxent f1);
recast float mxent;
lab var mxent "Entertainment Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxent=0 if mxent==.;
replace mxent=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;

** comm04;
use step00;
drop if rnfs_c~=4;
collapse rnfs_a flag, by(hhid) sum(mxpcare f1);
recast float mxpcare;
lab var mxpcare "Personal Care Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxpcare=0 if mxpcare==.;
replace mxpcare=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;

** comm05;
use step00;
drop if rnfs_c~=5;
collapse rnfs_a flag, by(hhid) sum(mxnews f1);
recast float mxnews;
lab var mxnews "Newspapers Etc. Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxnews=0 if mxnews==.;
replace mxnews=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;

** comm06;
use step00;
drop if rnfs_c~=6;
collapse rnfs_a flag, by(hhid) sum(mxtel f1);
recast float mxtel;
lab var mxtel "Telephone Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxtel=0 if mxtel==.;
replace mxtel=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;

** comm07;
use step00;
drop if rnfs_c~=7;
collapse rnfs_a flag, by(hhid) sum(mxcar f1);
recast float mxcar;
lab var mxcar "Vehicle Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxcar=0 if mxcar==.;
replace mxcar=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;

** comm08;
use step00;
drop if rnfs_c~=8;
collapse rnfs_a flag, by(hhid) sum(mxtran f1);
recast float mxtran;
lab var mxtran "Transportation Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxtran=0 if mxtran==.;
replace mxtran=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;

** comm09;
use step00;
drop if rnfs_c~=9;
collapse rnfs_a flag, by(hhid) sum(mxwash f1);
recast float mxwash;
lab var mxwash "Washing Supplies Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxwash=0 if mxwash==.;
replace mxwash=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;

** comm10;
use step00;
drop if rnfs_c~=10;
collapse rnfs_a flag, by(hhid) sum(mxchil f1);
recast float mxchil;
lab var mxchil "Day Care Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxchil=0 if mxchil==.;
replace mxchil=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;

** comm11;
use step00;
drop if rnfs_c~=11;
collapse rnfs_a flag, by(hhid) sum(mxdues f1);
recast float mxdues;
lab var mxdues "Dues Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxdues=0 if mxdues==.;
replace mxdues=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;

** comm12;
use step00;
drop if rnfs_c~=12;
collapse rnfs_a flag, by(hhid) sum(mxdon f1);
recast float mxdon;
lab var mxdon "Donations Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxdon=0 if mxdon==.;
replace mxdon=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;

** comm13;
use step00;
drop if rnfs_c~=13;
collapse rnfs_a flag, by(hhid) sum(mxhelp f1);
recast float mxhelp;
lab var mxhelp "Household Help Exp.";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxhelp=0 if mxhelp==.;
replace mxhelp=. if f1==1 ;
drop f1;
sort hhid;
save nf1x01,replace;


** CALCULATE THE TOTAL EXPENDITURE VARIABLE         **
;
** commTOT;
use step00;
collapse rnfs_a flag, by(hhid) sum(mxtot flag);
recast int flag;
recast float mxtot;
lab var mxtot "Tot Non Food Month Exp";
lab var flag "With Missing Values";
save step01,replace;

use nf1x01;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxtot=0 if mxtot==.;
replace mxtot=. if flag>0 & flag~=.;
sort hhid;
save nf1x01,replace;
    

!del step00.dta;
!del step01.dta;

log close;
