#delimit ;

log using do\calcnf2x,replace;
set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CALCNF2x.DO              V : 01              *;
*    Date    : JULY 7, 1994                                 *;
*    Infile  : M3_NFS2                                      *;
*    Outfile : NF2X02                                       *;
*                                                           *;
*    OBJECTIVE: Calculate the values of expenditure for     *;
*               each of the occasional non food commodities *;
*                                                           *;
*************************************************************;
set more 1;

clear;
set maxobs 45000;
use m3_nfs2;
des;
sum;

***  CHECK THE MISSING OF THE NON FOOD OCCASIONAL EXPENDITURES  **;

gen flag=1 if onfs_a<0;
replace onfs_a=. if flag==1;
tab onfs_c, sum(flag);
save step00,replace;

use s4_hdef;
keep hhid;
sort hhid;
lab data "Non Food occasional: Year Expenditure";
save nf2x02,replace;

*_NOTE: There are several true missing (Do not Know and refusals) values 
        which are set to missing.  Non reporting exenditure is set to 
        zero.  There are in total approximately 748 households that do not
        report any expenditure: they are set to zero
;

** CALCULATE THE INDIVIDUAL EXPENDITURE VARIABLES **;

** comm01;
use step00;
drop if onfs_c~=1;
collapse onfs_a flag, by(hhid) sum(yxkit f1);
recast float yxkit;
lab var yxkit "Kitchen equipments";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxkit=0 if yxkit==.;
replace yxkit=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;


** comm02;
use step00;
drop if onfs_c~=2;
collapse onfs_a flag, by(hhid) sum(yxhom f1);
recast float yxhom;
lab var yxhom "Home rep/maint.";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxhom=0 if yxhom==.;
replace yxhom=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;

** comm03;
use step00;
drop if onfs_c~=3;
collapse onfs_a flag, by(hhid) sum(yxbed f1);
recast float yxbed;
lab var yxbed "Bedding/Towels etc.";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxbed=0 if yxbed==.;
replace yxbed=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;

** comm04;
use step00;
drop if onfs_c~=4;
collapse onfs_a flag, by(hhid) sum(yxfurn f1);
recast float yxfurn;
lab var yxfurn "Furniture/Appliance";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxfurn=0 if yxfurn==.;
replace yxfurn=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;

** comm05;
use step00;
drop if onfs_c~=5;
collapse onfs_a flag, by(hhid) sum(yxshoe f1);
recast float yxshoe;
lab var yxshoe "Shoes";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxshoe=0 if yxshoe==.;
replace yxshoe=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;

** comm06;
use step00;
drop if onfs_c~=6;
collapse onfs_a flag, by(hhid) sum(yxclth f1);
recast float yxclth;
lab var yxclth "Clothes";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxclth=0 if yxclth==.;
replace yxclth=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;

** comm07;
use step00;
drop if onfs_c~=7;
collapse onfs_a flag, by(hhid) sum(yxcmat f1);
recast float yxcmat;
lab var yxcmat "cloth materials.";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxcmat=0 if yxcmat==.;
replace yxcmat=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;

** comm08;
use step00;
drop if onfs_c~=8;
collapse onfs_a flag, by(hhid) sum(yxdoc f1);
recast float yxdoc;
lab var yxdoc "Dentists/Doctors/Nurses";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxdoc=0 if yxdoc==.;
replace yxdoc=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;

** comm09;
use step00;
drop if onfs_c~=9;
collapse onfs_a flag, by(hhid) sum(yxhfee f1);
recast float yxhfee;
lab var yxhfee "Hospital Fees";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxhfee=0 if yxhfee==.;
replace yxhfee=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;

** comm10;
use step00;
drop if onfs_c~=10;
collapse onfs_a flag, by(hhid) sum(yxmedsp f1);
recast float yxmedsp;
lab var yxmedsp "Medical Supplies";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxmedsp=0 if yxmedsp==.;
replace yxmedsp=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;

** comm11;
use step00;
drop if onfs_c~=11;
collapse onfs_a flag, by(hhid) sum(yxtrad f1);
recast float yxtrad;
lab var yxtrad "Traditional Healer";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxtrad=0 if yxtrad==.;
replace yxtrad=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;

** comm12;
use step00;
drop if onfs_c~=12;
collapse onfs_a flag, by(hhid) sum(yxholi f1);
recast float yxholi;
lab var yxholi "Holidays";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxholi=0 if yxholi==.;
replace yxholi=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;

** comm13;
use step00;
drop if onfs_c~=13;
collapse onfs_a flag, by(hhid) sum(yxlux f1);
recast float yxlux;
lab var yxlux "Luxury Goods";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxlux=0 if yxlux==.;
replace yxlux=. if f1==1 ;
drop f1;
sort hhid;
save nf2x02,replace;


** CALCULATE THE TOTAL EXPENDITURE VARIABLE         **
;
** commTOT;
use step00;
collapse onfs_a flag, by(hhid) sum(yxtot flag);
recast int flag;
recast float yxtot;
lab var yxtot "Tot Non Food Yearly Exp";
lab var flag "With Missing Values";
save step01,replace;

use nf2x02;
merge hhid using step01;
tab _merge;
drop _merge;
replace yxtot=0 if yxtot==.;
replace yxtot=. if flag>0 & flag~=.;
sort hhid;
save nf2x02,replace;



!del step00.dta;
!del step01.dta;

log close;
