#delimit ;

log using do\calcq05,replace;
*************************************************************;
*                                                           *;
*    Name    : CALCQ05.DO               V : 01              *;
*    Date    : JULY 26,1994                                 *;
*    Infile  : FOODQC01,HHSIZE,STRATA2,FOODC1               *;
*    Outfile : FOODQC02                                     *;
*                                                           *;
*    OBJECTIVE: Replace missing values                      *;
*               obtain the total quantities and calculate   *;
*               Calories                                    *;
*                                                           *;
*************************************************************;
set more 1;
set maxobs 50000;

*                 MISSING CONSUMPTION VALUES                        
*
*    There are a total of 1357 missing consumption values in the data
*    Before checking for outliers it is important to replace them
*    with some reasonable values.  
*    The best alternative is to use Cluster per capita Medians by Race, as 
*    it was done in the case of the missing weekly data.  The assumption 
*    being that the consumption pattern is similar in the same cluster.
*    Only in case the cluster median is not available it is replaced by the
*    sample median.
*
;
use hhsize;
merge hhid using strata2;
tab _merge;
drop if _merge==2;
keep hhid hhsizem race;
sort hhid;
save st1,replace;

clear;
set maxobs 153000;
use foodqc01;
merge hhid using st1;
tab _merge;
drop if _merge~=3;
keep hhid foodcode race hhsizem mqcons flag;

gen clust=int(hhid/1000);
gen pcmqcon=mqcon/hhsizem;

sort clust foodcode race;
save st1,replace;
des;

egen clpcmed =median(pcmqcon) if flag==2, by(clust foodcode race);
collapse clpcmed , max(clpcmed) by(clust race foodcode);
des;
sum;
sort clust foodcode race;
save st2,replace;

use st1;
egen pcmed=median(pcmqcon) if flag==2, by(foodcode);
collapse pcmed , max(pcmed) by(foodcode);
des;
sum;
sort foodcode;
save st3,replace;

**  Put the median values back into the original file  **;

use st1;
merge clust foodcode race using st2;
tab _merge;
drop _merge;
sort foodcode;
merge foodcode using st3;
tab _merge;
drop _merge;
des;
sum;

gen missa=clpcmed*hhsizem if flag==4;
gen missb=pcmed*hhsizem if flag==4 & missa==.;
keep if flag==4;
keep hhid foodcode missa missb;
sort hhid foodcode;
des;
tab food,sum(missa);
tab food,sum(missb);
sort hhid foodcode;
save st1,replace;

***  Replace the missing values so calculated in the main file  **
;
use foodqc01;
merge hhid foodcode using st1;
tab _merge;
drop _merge;
replace mqcons=missa if mqcons==.;
replace mqcons=missb if mqcons==.;

drop missa missb;
!del st1.dta;
!del st2.dta;
!del st3.dta;

sort foodcode;

*****   Calculate the Daily calories for the commodities      ** 
;
merge foodcode using fcode1;
tab _merge;
drop _merge;

drop conv_k;
gen daycal=mqcons*conv_cal/30;
lab var daycal "Daily Calories";

drop conv_cal;

sort hhid foodcode;
save foodqc02,replace;
des;
sum;
tab foodcode if mqcons>0, sum(mqcons);


log close;


