#delimit ;

log using do\calcstx1, replace;
set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CALCSTX1.DO             V : 01               *;
*    Date    : JULY 7, 1994                                 *;
*    Infile  : M2_NFS3, HHISZE, STRATA2                     *;
*    Outfile : HHSTX01                                      *;
*                                                           *;
*    OBJECTIVE: Calculate the Total values of summary       *;
*               expenditure.                                *;
*               Use the most relavant variable and replace  *;
*               missing values with cluster and race median *;
*                                                           *;
*************************************************************;
set more 1;
clear;

set maxobs 35000;
use m2_nfs3;
des;

*** GET AND CALCULATE RELEVANT VARIABLES FOR TOTAL SUMMARY EXPENDITURE **                                        **
    There are 3 types of variables, Last monsth, Usual and last year   **
    The order is : 1) Usual, 2) Last Year, 3) Last Month               **
    NOTE : There are 36 households that do not spend any money
           They are set to zero
;
keep hhid sumexp_c sumexp_a sumexp_1 sumexp_2;

gen mark=0;
replace mark=1 if sumexp_a<0| sumexp_1<0| sumexp_2<0;

gen sexp=0;
replace sexp=sumexp_1 if sumexp_1>0 & sumexp_1~=.;
replace sexp=int(sumexp_2/12) if sexp==0 & sumexp_2>0 & sumexp_2~=.;
replace sexp=sumexp_a if sexp==0 & sumexp_a>0 & sumexp_a~=.;
replace sexp=. if sexp==0 & mark==1;

gen flago=0;
replace flago=1 if sexp==.;

tab sumexp_c, sum(sexp);
tab sumexp_c if mark==1, sum(sexp);
tab sumexp_c if flago==1;
      
*** REPLACE MISSING WITH CLUSTER MEDIAN OF NON-ZERO OBS ***;

* Get the hhisize and race variables **
;
sort hhid;
merge hhid using hhsize;
tab _merge;
drop if _merge~=3;
drop _merge;
drop hhsizep;

sort hhid;
merge hhid using strata2;
tab _merge;
drop if _merge~=3;
drop _merge;

gen clust=int(hhid/1000);
gen pcsexp=sexp/hhsizem;

egen medsexp=median(pcsexp), by (clust race sumexp_c);

replace sexp=int(medsexp*hhsizem) if sexp==.;

keep hhid sumexp_c sexp flago;
sort hhid sumexp_c;
save step10, replace;


** Mark the values that are still Missing  **
;
gen flag=0;
replace flag=1 if sexp==.;
gen flagr=0;
replace flagr=1 if flago==1 & flag==0;

lab var flago "Original Missing"; 
lab var flagr "Replaced Missing"; 
lab var flag "Still Missing"; 

save step101, replace;

tab flago flagr;
tab flago flag;

** SET UP THE FILE    **
;
use s4_hdef;
keep hhid;
sort hhid;
lab data "Summary Expenditure";
save hhstx01,replace;

** CREATE THE INDIVIDUAL VARIABLES FOR THE DIFFERENT COMMODITIES **;

** comm01;
use step101;
drop if sumexp_c~=1;
collapse sexp flag, by(hhid) sum(stxgroc f1);
recast float stxgroc;
lab var stxgroc "Groceries.";
save step02,replace;

use hhstx01;
merge hhid using step02;
tab _merge;
drop _merge;
replace stxgroc=0 if stxgroc==.;
replace stxgroc=. if f1==1; 
drop f1;
sort hhid;
save hhstx01,replace;

** comm02;
use step101;
drop if sumexp_c~=2;
collapse sexp flag, by(hhid) sum(stxfood f1);
recast float stxfood;
lab var stxfood "Food eaten out.";
save step02,replace;

use hhstx01;
merge hhid using step02;
tab _merge;
drop _merge;
replace stxfood=0 if stxfood==.;
replace stxfood=. if f1==1 ;
drop f1;
sort hhid;
save hhstx01,replace;

** comm03;
use step101;
drop if sumexp_c~=3;
collapse sexp flag, by(hhid) sum(stxhol f1);
recast float stxhol;
lab var stxhol "Holidays.";
save step02,replace;

use hhstx01;
merge hhid using step02;
tab _merge;
drop _merge;
replace stxhol=0 if stxhol==.;
replace stxhol=. if f1==1;
drop f1;
sort hhid;
save hhstx01,replace;

** comm04;
use step101;
drop if sumexp_c~=4;
collapse sexp flag, by(hhid) sum(stxcars f1);
recast float stxcars;
lab var stxcars "Cars, etc.";
save step02,replace;

use hhstx01;
merge hhid using step02;
tab _merge;
drop _merge;
replace stxcars=0 if stxcars==.;
replace stxcars=. if f1==1;
drop f1;
sort hhid;
save hhstx01,replace;

** comm05;
use step101;
drop if sumexp_c~=5;
collapse sexp flag, by(hhid) sum(stxfurn f1);
recast float stxfurn;
lab var stxfurn "Furniture.";
save step02,replace;

use hhstx01;
merge hhid using step02;
tab _merge;
drop _merge;
replace stxfurn=0 if stxfurn==.;
replace stxfurn=. if f1==1;
drop f1;
sort hhid;
save hhstx01,replace;

** comm06;
use step101;
drop if sumexp_c~=6;
collapse sexp flag, by(hhid) sum(stxcloth f1);
recast float stxcloth;
lab var stxcloth "Clothing.";
save step02,replace;

use hhstx01;
merge hhid using step02;
tab _merge;
drop _merge;
replace stxcloth=0 if stxcloth==.;
replace stxcloth=. if f1==1;
drop f1;
sort hhid;
save hhstx01,replace;

** comm07;
use step101;
drop if sumexp_c~=7;
collapse sexp flag, by(hhid) sum(stxhelp f1);
recast float stxhelp;
lab var stxhelp "domestic workers.";
save step02,replace;

use hhstx01;
merge hhid using step02;
tab _merge;
drop _merge;
replace stxhelp=0 if stxhelp==.;
replace stxhelp=. if f1==1;
drop f1;
sort hhid;
save hhstx01,replace;

** comm08;
use step101;
drop if sumexp_c~=8;
collapse sexp flag, by(hhid) sum(stxinsur f1);
recast float stxinsur;
lab var stxinsur "Insurance.";
save step02,replace;

use hhstx01;
merge hhid using step02;
tab _merge;
drop _merge;
replace stxinsur=0 if stxinsur==.;
replace stxinsur=. if f1==1;
drop f1;
sort hhid;
save hhstx01,replace;

** comm09;
use step101;
drop if sumexp_c~=9;
collapse sexp flag, by(hhid) sum(stxsav f1);
recast float stxsav;
lab var stxsav "Saving.";
save step02,replace;

use hhstx01;
merge hhid using step02;
tab _merge;
drop _merge;
replace stxsav=0 if stxsav==.;
replace stxsav=. if f1==1;
drop f1;
sort hhid;
save hhstx01,replace;

** Calculate the totals for SUMMARY EXPENDITURE  **
;
** commTOT;
use step101;
collapse sexp flago flagr flag, by(hhid) sum(stxtot flag flag1 flag2);
recast float stxtot;
lab var stxtot "Summary Exp: total";

recast int flag*;
lab var flag  "With Original Missing Values";
lab var flag1 "With Replaced Missing Values";
lab var flag2 "With Values Still Missing";

save step02,replace;

use hhstx01;
sort hhid;
merge hhid using step02;
tab _merge;
drop _merge;
replace flag=0  if flag==.;
replace flag1=0 if flag1==.;
replace flag2=0 if flag2==.;

replace stxtot=0 if stxtot==.;
replace stxtot=. if flag2>=1 ;

gen int marker10=0;
replace marker=1 if flag==0 ;
replace marker=2 if flag1>=1 & flag2==0 ;

lab var marker "Marker";
lab def mark 0 "Miss"
             1 "Orig"
             2 "Impute";
lab val marker mark;

tab marker10;

drop flag*;
sort hhid;          

save hhstx01,replace;

**_________________File Clean up
;
!del step10.dta;
!del step101.dta;
!del step02.dta;

log close;
