#delimit ;

log using do\calcx02,replace;
*************************************************************;
*                                                           *;
*    Name    : CALCX02.DO               V : 10              *;
*    Date    : JULY 26,1994                                 *;
*    Infile  : FOODEX10, FCODE1, CFPRI03                    *;
*    Outfile : STPX02                                       *;
*                                                           *;
*    OBJECTIVE: Calculate the monthly expenditure of food   *;
*               received                                    *;
*                                                           *;
*************************************************************;
set more 1;
set maxobs 153000;

** Get the Prices ready  **
;
use cfpri03;
keep clust foo cfpri;
sort food;
merge food using fcode1;
tab _merge;
drop if _merge==2;
drop _merge;
keep clust food cfpri conv_k;
sort clust food;
des;
save tq1,replace;

** Get a working file   **
;
use foodex10;
des;

*   Work on a smaller file and merge conversion file to it  *
*   Keep the relevant information and delete the missing    * 
;
keep
  hhid
  foodcode
  weekly
  receive_
  receive1
  flag13;

drop if flag==4 | receive_==0 & receive1==0;

** Get the Prices in
;
gen clustnum=int(hhid/1000);
sort clust foodcode;
merge clust foodcode using tq1;
tab _merge;
drop if _merge==2;
drop _merge;
!del tq1.dta;
drop clust;

*     Check the weekly 
;
tab foodcode weekly;

*     Convert Quantities and Values into Values.  Use the value if    *
*     reported and the quantities converted into Kg otherwise         *
;
gen receiv_x=0;
replace receiv_x=receive_  if receive_>0;
replace receiv_x=receive1*conv_k*cfpri  
              if receive1>0 & receive_<=0 & cfpri>0;
drop receive1 receive_ conv_k cfpri;

*     Calculate monthly consumption (If weekly is missing set to 
*     Most frequent occurance by cluser - i.e.  It is possible that  
*     Each commodity is purchased according to a different pattern
*     in each area.  For example Mealie Meal is purchased on a 
*     monthly basis and fresh vegetables on a weekly basis.  And in some 
*     areas shopping is done only on a monthly basis.)
*     If cluster information is not available use Total
;
gen clust=int(hhid/1000);

gen int a=1 if weekly==1;
gen int b=1 if weekly==2;
egen int nweek=count(a), by(clust foodcode);
egen int nmonth=count(b), by(clust foodcode);

gen dif=0;
replace dif=1 if nweek~=.  & nmonth==.;
replace dif=1 if nmonth~=. & nweek~=. & nmonth<nweek;
replace dif=2 if nmonth~=. & nweek==. ;
replace dif=2 if nmonth~=. & nweek~=. & nmonth>nweek;
tab dif;

drop nmonth nweek;

egen int nweek=count(a), by(foodcode);
egen int nmonth=count(b), by(foodcode);

replace dif=1 if dif==0 & nmonth~=. & nweek~=. & nmonth<nweek;
replace dif=2 if dif==0 & nmonth~=. & nweek~=. & nmonth>nweek;

tab dif;

drop nmonth nweek;
drop a b;

gen cweek=0;
lab var cweek "Weekly conversion";
replace cweek=1 if weekly==2;
replace cweek=1 if weekly<0 & dif==2;
replace cweek=4.3 if weekly==1;
replace cweek=4.3 if weekly<0 & dif==1;

tab cweek weekly;

tab foodcode cweek if weekly<0;

gen mxrec=receiv_x;
replace mxrec=receiv_x*cweek;
lab var mxrec "Monthly value received";

sort foodcode;

tab foodcode if weekly>0, sum(mxrec);
tab foodcode if weekly<0, sum(mxrec);

keep
  hhid
  foodcode
  weekly
  mxrec;
sort hhid foodcode;

des;
sum;
tab foodcode if mxrec>0, sum(mxrec);

save stpx02,replace;

log close;
