#delimit ;

log using do\calcxs01,replace;
*************************************************************;
*                                                           *;
*    Name    : CALCXS01.DO              V : 01              *;
*    Date    : JULY 26, 1994                                *;
*    Infile  : FOODEX02, HHSIZE                             *;
*    Outfile : HHFEXP                                       *;
*                                                           *;
*    OBJECTIVE: calculate total monthly expenditure         *;
*               for commodities groups and get the shares   *;
*                                                           *;
*************************************************************;
set more 1;
set maxobs 153000;

use foodex02;

des;

keep hhid foodcode mxcons;
sort hhid;

**  Calculate per capita expenditure values using file hhsize   **
**  and the variable hhsizem which includes all members  in     **
**  the household                                               **   
;
merge hhid using hhsize;
tab _merge;
drop _merge;

gen pcexp=mxcons/hhsizem;

drop hhsizep;

sort hhid;

save step00,replace;

**  CALCULATE COMMODITY GROUPS.  
**  NOTE: The other category is different than in the calorie file
**        here it contains also commodity 31
**        In addition there is category: Meals (Food away from home 
**        and to guests)
;

*  Calculate the variables for the first part  ;
egen ptxgrain=sum(pcexp)
               if foodcode>=1 & foodcode<=6 ,by(hhid);
egen ptxmeafi=sum(pcexp)
               if foodcode>=18 & foodcode<=22 ,by(hhid);
collapse 
     hhsizem ptxgrain ptxmeafi, 
     by(hhid)
     max(hhsizem ptxgrain ptxmeafi);

sort hhid;

save step01,replace;

*  Calculate the variables for the second part  ;
use step00;

egen ptxdairy=sum(pcexp)
               if foodcode==13 | foodcode>=15 & foodcode<=16 ,by(hhid);
egen ptxfruve=sum(pcexp)
               if foodcode>=7 & foodcode<=10 |
                  foodcode>=23 & foodcode<=27  ,by(hhid);
collapse 
     ptxdairy ptxfruve, by(hhid)
     max(ptxdairy ptxfruve);

sort hhid;

save step02,replace;

*  Calculate the variables for the third part ;
use step00;

egen ptxoils =sum(pcexp)
               if foodcode>=11 & foodcode<=12  ,by(hhid);
egen ptxsugar=sum(pcexp)
               if foodcode==17 ,by(hhid);
collapse 
     ptxoils ptxsugar, by(hhid)
     max(ptxoils ptxsugar);

sort hhid;

save step03,replace;

*  Calculate the variables for the fourth part ;
use step00;

egen ptxmeals=sum(pcexp)
               if foodcode==29 | foodcode==30 ,by(hhid);
egen ptxother=sum(pcexp)
               if foodcode==14 | foodcode==28 | foodcode==31 ,by(hhid);
collapse 
     ptxmeals ptxother, by(hhid)
     max(ptxmeals ptxother);

sort hhid;

save step04,replace;

*  Calculate the variables for the fifth part ;
use step00;

egen pctfexp=sum(pcexp), by(hhid);
egen hhtfexp=sum(mxcons), by(hhid);

collapse 
     pctfexp hhtfexp, by(hhid)
     max(pctfexp hhtfexp);

sort hhid;

save step05,replace;

!del step00.dta;

*  Merge all the parts togehter ;

clear;

set maxobs 10000;

use step01;

merge hhid using step02;
drop _merge;
sort hhid;

merge hhid using step03;
drop _merge;
sort hhid;

merge hhid using step04;
drop _merge;
sort hhid;

merge hhid using step05;
drop _merge;
sort hhid;

lab data "Per capita month expend.";
lab var ptxgrain "Per capita grain month exp.";
lab var ptxmeafi "Per capita meat & fish month exp.";
lab var ptxdairy "Per capita dairy month exp.";
lab var ptxfruve "Per capita fru. and veg. month exp.";
lab var ptxoils "Per capita oil month exp.";
lab var ptxsugar "Per capita sugar month exp.";
lab var ptxmeals "Per capita meals month exp.";
lab var ptxother "Per capita other month exp.";
lab var pctfexp "Per capita tot food month exp.";
lab var hhtfexp "Household tot food month exp.";

**  Check if the total month exp. derived from the two mathods **;
**  give the same results                                      **;

egen pctot=rsum(ptx*);
sum pctot pctfexp;
drop pctot;

sort hhid;

** Mark the Missing values for all the households that do not report
   any food expenditure at all and set to Zero all the individual
   commodity expenditure that are not reported.
;
replace pctfexp=. if pctfexp==0;
replace hhtfexp=. if hhtfexp==0;

replace ptxgrain = 0 if ptxgrain ==. & pctfexp~=.;
replace ptxmeafi = 0 if ptxmeafi ==. & pctfexp~=.;
replace ptxdairy = 0 if ptxdairy ==. & pctfexp~=.;
replace ptxfruve = 0 if ptxfruve ==. & pctfexp~=.;
replace ptxoils  = 0 if ptxoils  ==. & pctfexp~=.;
replace ptxsugar = 0 if ptxsugar ==. & pctfexp~=.;
replace ptxmeals = 0 if ptxmeals ==. & pctfexp~=.;
replace ptxother = 0 if ptxother ==. & pctfexp~=.;

***  Generate expenditure shares. By default only the households that  **;
***  have at least some total month expenditure are included           **;

gen sxgrain = 100*ptxgrain/pctfexp;
gen sxmeafi = 100*ptxmeafi/pctfexp;
gen sxdairy = 100*ptxdairy/pctfexp;
gen sxfruve = 100*ptxfruve/pctfexp;
gen sxoils  = 100*ptxoils/pctfexp;
gen sxsugar = 100*ptxsugar/pctfexp;
gen sxmeals = 100*ptxmeals/pctfexp;
gen sxother = 100*ptxother/pctfexp;

lab var sxgrain "Share grain month exp.";
lab var sxmeafi "Share meat & fish month exp.";
lab var sxdairy "Share dairy month exp.";
lab var sxfruve "Share fru. and veg. month exp.";
lab var sxoils  "Share oil month exp.";
lab var sxsugar "Share sugar month exp.";
lab var sxmeals "Share meals month exp.";
lab var sxother "Share other month exp.";

save hhfexp,replace;

!del step01.dta;
!del step02.dta;
!del step03.dta;
!del step04.dta;
!del step05.dta;

des;
sum;

sum hhtfexp, det;
sum pctfexp, det;

log close;
