#delimit ;

log using do\clcexp04,replace;
set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP04.DO              V : 01              *;
*    Date    : AUGUST 5, 1994                               *;
*    Infile  : S4_HSV1,STRATA2                              *;
*    Outfile : HHEXP04                                      *;
*                                                           *;
*    OBJECTIVE: Calculate Actual and Inputed Housing        *;
*               Expenditure                                 *;
*                                                           *;
*************************************************************;
set more 1;

** The Calculation of the housing cost is obtained using the following 
   measurements:

   1) The actual value of the rent paid or an extimate of the 
      the rental value of the house if is is provided for free
      by sombody else. 
   2) Estimate of the rental value based on the ratio of property value   
      and rental value in the same area for all the people that report
      the resale value of their homes.  
   3) Estimation of the value of the homes for all the poeple that do not  
      provide the cost of rent nor the value of their homes, so as to use 
      the same ratio for the estimation of the rental value.
;

**  Get the files                **
;
use s4_hdef;
keep hhid;
sort hhid;

merge hhid using s4_hsv1;
tab _merge;
drop _merge;
sort hhid;

merge hhid using strata2;
tab _merge;
drop _merge;
sort hhid;
gen clustnum=int(hhid/1000);


***   ACTUAL OR ESTIMATES RENTAL EXPENDITURE  (use values above R10) ***
;
gen rentexp=rent_a if rent_a>10;
replace rentexp=rent_m if rent_m>10 & rentexp==.;
lab var rentexp "Actual Rental Expenses";
gen int marker04=0;
lab var marker04 "Marker";
replace marker04=1 if rentexp>0 & rentexp~=. & rent_a>10; *Have actual rent ;
replace marker04=2 if rentexp>0 & rentexp~=. & rent_m>10; *Have market rent ;
replace marker04=3 if marker04==0 & sale>0 & sale~=.;     *Have Value;
replace rooms_to=. if rooms_to<0;                     ** To avoid negatives;


**   ESTIMATE THE VALUE OF THE HOUSE FOR ALL THE PEOPLE WITH NO VALUE 
**   OR NO RENT AND NO VALUE
;
** Get number of rooms for those with missing - use cluster and race
; 
egen mdroom=median(rooms_to), by(clust race);
replace rooms_t=mdroom if rooms_t==. & mdroom>0 & mdroom~=.;
sort hhid;
save stex01,replace;


** Get the median value by cluster   **
;
gen valroom=sale_val/rooms_to;
egen mdvalrm=median(valroom) if valroom>0, by(clust);
collapse mdvalrm, max(mdvalrm) by(clust);
des;
sum;
sort clust;
save stex02,replace;

** By New province metro and race   **
;
use stex01;
gen valroom=sale_val/rooms_to;
egen mdvalrm2=median(valroom) if valroom>0, by(newp metro race);
collapse mdvalrm2, max(mdvalrm2) by(newp metro race);
des;
sum;
sort newp metro race;
save stex03,replace;


**  Put the median values back in the file **
;
use stex01;
keep hhid clust marker04 rooms_to newp metro race;
sort clust;
merge clust using stex02;
tab _merge;
drop _merge;

sort newp metro race;
merge newp metro race using stex03;
tab _merge;
drop _merge;

gen mdval=mdvalrm*rooms_to;
replace mdval=mdvalrm2*rooms_to if mdval==.;

des;
sum;
keep if marker04==0;
sort hhid;
save stex04,replace;

use stex01;
merge hhid using stex04;
tab _merge;
drop _merge;
replace sale=mdval if marker04==0;

tab newpro if marker04==0, sum(sale);
tab newpro if marker04==1, sum(sale);
tab newpro if marker04==2, sum(sale);
tab newpro if marker04==3, sum(sale);

replace marker04=4 if marker04==0 & sale>0 & sale~=.;
lab def mar 0 "Miss"
            1 "Rent_a"
            2 "Rent_m"
            3 "Val "
            4 "No Re/Val" 
            5 "Impute";
lab val marker04 mar;

save stex01,replace;


***  Check the ratio: value to rental by province metro and race  **
;
use stex01;
egen valmed = median(sale_val) if sale_val>0 , by(newpr metro race);
egen rentmed= median(rentexp)  if rentexp>0  , by(newpr metro race);
egen numrent= count(rentexp)   if rentexp>0  , by(newpr metro race);
egen numval = count(sale_val)  if sale_val>0 , by(newpr metro race);

collapse rentmed valmed numrent numval , 
         max(rentmed valmed numrent numval) by(newpr metro race);
gen ratio = rent*1200/val if rent>0 & val>0;

egen mdratio=median(ratio), by(metro race);
collapse mdratio , max(mdratio) by(metro race);
des;
list;
save stex05,replace;


*** CALCULATE IMPUTED VALUE OF RENT USING REPORTED AND ESTIMATED SALE  
    VALUE OF THE PROPERTY AND RENTAL RATIO BY LOCATION AND RACE
;
use stex01;
sort metro race;
merge metro race using stex05;
tab _merge;
drop _merge;

gen rentimp=sale*mdratio/1200 ;
replace rentimp=. if marker04==1 | marker04==2;
lab var rentimp "Imputed Rental Expenses";

*** REPLACE REMANING VALUES WITH CLUSTER MEDIANS - In three clusters   
    they are still missing because nobody has a value of the house 
    in which they are, because everybody else is renting.  
;
gen rentroom=rentexp/rooms_t;
egen mdrtrom=median(rentroom), by(clust race);

replace mdrtrom = 20 if clust==40 & 
                        mdrtrom==. ; * Median for 2 Coloured in African area;

gen mdrt=mdrtrom*rooms_t;

replace marker04=5 if marker04==0 & mdrt>0 & mdrt~=.;
replace rentimp=mdrt if marker04==5;


**  SAVE THE RESULTS IN A FILE  **
;
keep hhid rentexp rentimp marker04;
lab data "Rental Expenditure";

egen mxtrent=rsum(rentimp rentexp);
replace mxtrent=. if marker04==0;
lab var mxtrent "Total Housing Expenditure";

sort hhid;
des;
sum;

save hhexp04,replace;

** DELETE UNECESSARY FILES   **
;
!del stex01.dta;
!del stex02.dta;
!del stex03.dta;
!del stex04.dta;

log close;
