#delimit ;

log using do\clcexp06,replace;
set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP06.DO              V : 01              *;
*    Date    : JULY 21, 1994                                *;
*    Infile  : M3_HSV4, S3_HSV3                             *;
*    Outfile : HHEXP06                                      *;
*                                                           *;
*    OBJECTIVE: Calculate the total values of actual        *;
*               expenditure for utilities which include:    *;
*               energy, water, rates and more               *;
*************************************************************;
set more 1;

**  NOTE: There are about 600 households that do not report any 
          Expenditure for energy.  Most times it is in the case
          of boycott or other reasons for which they do not pay
          for utilities or rates.  ALL THIS OBSERVATIONS HAVE
          BEEN SET TO ZERO for the calculations of actual expenditure
;  

clear;
set maxobs 45000;
use m3_hsv4;
des;
sum;

***  CHECK THE MISSING VALUES  **;

gen flag=1 if exp_a<0;
replace exp_a=. if flag==1;

tab exp_c, sum(flag);

save step00,replace;


** FILL IN THE MISSING VALUES for the net values that was refused or                      
   "Do not know" with zero for some Hostel dwellers and by medians by 
   cluster and race for the others.
;

sort hhid;
merge hhid using strata2;
tab _merge;
drop if _merge~=3;
drop _merge;
gen clustnum=int(hhid/1000);

save stexp60,replace;


**  Collapse individual item by Occupation and Race;

egen medval=median(exp_a), by(exp_c clust race); 
collapse medval flag, 
       max(medval  . ) sum( . missobs) by(exp_c clust race); 

format medval %9.2f;
sort exp_c clust race;
des;

tab exp_c if missobs==0, sum(medval);
tab exp_c if missobs==1, sum(medval);

des;
save stexp61,replace;

** Put the values back into the file  **
;
use stexp60;
sort exp_c clust race;
merge exp_c clust race using stexp61;
tab _merge ;
drop _merge;

keep hhid exp_c medval;
sort hhid exp_c;
save stexp62,replace;

use step00;
sort hhid exp_c;
merge hhid exp_c using stexp62;
tab _merge;
drop _merge;

gen flag1=1 if flag==1 & medval>=0 & medval~=.;  * Flag Replaced value *;
gen flag2=1 if flag==1 & flag1~=1;              * Flag Still missing values *;
replace exp_a=medval if flag==1 & medval>=0   ;     

tab flag ;
tab flag1;
tab flag2;
sort hhid; 

tab exp_c if flag==0, sum(exp_a);    ** Original Values  **;
tab exp_c if flag1==1, sum(exp_a);   ** Replaced Values  **;
tab exp_c if flag2~=1, sum(exp_a);   ** All Values       **;

save step00,replace;


** Replace remaining missing values with zeroes in the case of the two 
   mining Hostels Cluster 87 (25 cases) and Cluster 100 (11 cases). 
   All other People leaving in the Hostel do not pay for Utilities 
   since housing is provided by the mine.
;
gen clust=int(hhid/1000);

replace flag1=1 if exp_a==. & (clust==87 | clust==100);
replace flag2=. if exp_a==. & (clust==87 | clust==100);

replace exp_a=0 if exp_a==. & (clust==87 | clust==100);   

drop clust;
save step00,replace;

*_________________END of the missing value section  **
;

***  SET UP THE FILE   **
;
use s4_hdef;
keep hhid;
gen cluster=int(hhid/1000);
sort hhid;
lab data "Utilities expenditure";
save hhexp06,replace;


***  CALCULATE THE INDIVIDUAL EXPENDITURE VARIABLES  ***
     All non recorded values are all assumed to be zero
     therefore only true missing values are reset to missing.
     After including all those zeros, now there might me enough data 
     to reset some other missing to zero, if that is prevailing in the
     cluster.
;

** comm01;
use step00;
drop if exp_c~=1;
collapse exp_a flag2, by(hhid) sum(mxwood f2);
recast float mxwood;
lab var mxwood "Wood Exp.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxwood=0 if mxwood==.;
replace mxwood=. if f2==1 ;
egen md=median(mxwood), by(clust);
replace mxwood=md if f2==1 & md~=.;
drop md f2;
sort hhid;
save hhexp06,replace;


** comm02;
use step00;
drop if exp_c~=2;
collapse exp_a flag2, by(hhid) sum(mxparr f2);
recast float mxparr;
lab var mxparr "Paraffin Exp.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxparr=0 if mxparr==.;
replace mxparr=. if f2==1 ;
egen md=median(mxparr), by(clust);
replace mxparr=md if f2==1 & md~=.;
drop md f2;
sort hhid;
save hhexp06,replace;

** comm03;
use step00;
drop if exp_c~=3;
collapse exp_a flag2, by(hhid) sum(mxcoal f2);
recast float mxcoal;
lab var mxcoal "Charcoal/coal Exp.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxcoal=0 if mxcoal==.;
replace mxcoal=. if f2==1 ;
egen md=median(mxcoal), by(clust);
replace mxcoal=md if f2==1 & md~=.;
drop md f2;
sort hhid;
save hhexp06,replace;

** comm04;
use step00;
drop if exp_c~=4;
collapse exp_a flag2, by(hhid) sum(mxelec f2);
recast float mxelec;
lab var mxelec "Electricity Exp.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxelec=0 if mxelec==.;
replace mxelec=. if f2==1 ;
egen md=median(mxelec), by(clust);
replace mxelec=md if f2==1 & md~=.;
drop md f2;
sort hhid;
save hhexp06,replace;

** comm05;
use step00;
drop if exp_c~=5;
collapse exp_a flag2, by(hhid) sum(mxcandle f2);
recast float mxcandle;
lab var mxcandle "Candles Exp.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxcandle=0 if mxcandle==.;
replace mxcandle=. if f2==1 ;
egen md=median(mxcand), by(clust);
replace mxcand=md if f2==1 & md~=.;
drop md f2;
sort hhid;
save hhexp06,replace;

** comm06;
use step00;
drop if exp_c~=6;
collapse exp_a flag2, by(hhid) sum(mxgas f2);
recast float mxgas;
lab var mxgas "Gas Exp.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxgas=0 if mxgas==.;
replace mxgas=. if f2==1 ;
egen md=median(mxgas), by(clust);
replace mxgas=md if f2==1 & md~=.;
drop md f2;
sort hhid;
save hhexp06,replace;

** comm07;
use step00;
drop if exp_c~=7;
collapse exp_a flag2, by(hhid) sum(mxbatt f2);
recast float mxbatt;
lab var mxbatt "Batteries Exp.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxbat=0 if mxbat==.;
replace mxbat=. if f2==1 ;
egen md=median(mxbat), by(clust);
replace mxbat=md if f2==1 & md~=.;
drop md f2;
sort hhid;
save hhexp06,replace;

** comm08;
use step00;
drop if exp_c~=8;
collapse exp_a flag2, by(hhid) sum(mxdiesel f2);
recast float mxdiesel;
lab var mxdiesel "Diesel Exp.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxdiesel=0 if mxdiesel==.;
replace mxdiesel=. if f2==1 ;
egen md=median(mxdies), by(clust);
replace mxdies=md if f2==1 & md~=.;
drop md f2;
sort hhid;
save hhexp06,replace;

** comm09;
use step00;
drop if exp_c~=9;
collapse exp_a flag2, by(hhid) sum(mxother f2);
recast float mxother;
lab var mxother "Other Exp.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxother=0 if mxother==.;
replace mxother=. if f2==1 ;
egen md=median(mxoth), by(clust);
replace mxoth=md if f2==1 & md~=.;
drop md f2;
sort hhid;
save hhexp06,replace;

** comm10;
use step00;
drop if exp_c~=10;
collapse exp_a flag2, by(hhid) sum(mxwater f2);
recast float mxwater;
lab var mxwater "Water Exp.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxwater=0 if mxwater==.;
replace mxwater=. if f2==1 ;
egen md=median(mxwate), by(clust);
replace mxwate=md if f2==1 & md~=.;
drop md f2;
sort hhid;
save hhexp06,replace;

** comm11;
use step00;
drop if exp_c~=11;
collapse exp_a flag2, by(hhid) sum(mxrates f2);
recast float mxrates;
lab var mxrates "Rates Exp.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxrates=0 if mxrates==.;
replace mxrates=. if f2==1 ;
egen md=median(mxrate), by(clust);
replace mxrate=md if f2==1 & md~=.;
drop md f2;
sort hhid;
save hhexp06,replace;

** comm12;
use step00;
drop if exp_c~=12;
collapse exp_a flag2, by(hhid) sum(mxewr f2);
recast float mxewr;
lab var mxewr "Water, energy, rates if paid tog.";
save step01,replace;

use hhexp06;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxewr=0 if mxewr==.;    * Leave it to Zero for fear of double count;
drop f2;
sort hhid;
save hhexp06,replace;


***  CALCULATE THE TOTAL EXPENDITURES FOR UTILITIES **;

** commTOT;
use step00;
collapse exp_a flag flag1 flag2, by(hhid) sum(mxtot flag flag1 flag2);

recast float mxtot; 
recast int flag*;

save step01,replace;
use hhexp06;
sort hhid;
merge hhid using step01;
tab _merge;
drop _merge;


gen mxtutil = mxwood + mxparr + mxcoal + mxelec + mxcand +
              mxgas  + mxbat  + mxdies + mxother+ mxwater+
              mxrate + mxewr;
sum mxt*;
drop mxtot;

lab var mxtutil "Tot exp: energy, water, rates";
lab var flag  "With Original Missing Values";
lab var flag1 "With Replaced Missing Values";
lab var flag2 "With Values Still Missing";

replace flag=0  if flag==.;
replace flag1=0 if flag1==.;
replace flag2=0 if flag2==.;

gen int marker06=0;
replace marker=1 if flag==0 ;
replace marker=2 if flag1>=1 & flag2==0 ;

replace marker06=2 if marker06==0 & mxtutil~=.; 

lab var marker "Marker";
lab def mark 0 "Miss"
             1 "Orig"
             2 "Impute";
lab val marker mark;

tab marker06;

drop clust flag*;
sort hhid;          
save hhexp06,replace;
sum;


**  IMPUTE VALUE OF FIREWOOD COLLECTION  AND ADD TO TOTAL     **
**  Calculate the monthly imputed value for Wood collection:
    Assume a value of R2 per person per trip, Based on the fact that  
    a person could collect R10 worth of wood a week with 5 trips and
    approximately R50 a month worth of wood.
;
use s3_hsv3;
keep hhid wp* w_tr*;

*______________;  

*HHID 311008  has too many trips should be fixed **;
replace w_trips1=5 if hhid==311008;
*______________;

** Count the People
;
gen a=0;
replace a=1 if wpcode_1>0 | wpcode_1==-1;
gen b=0;
replace b=1 if wpcode_2>0 | wpcode_2==-1;
gen c=0;
replace c=1 if wpcode_3>0 | wpcode_3==-1;

gen woodpeop= a+b+c;
drop a b c;

** Count the trips
;
gen a=0;
replace a=w_trips_ if w_trips_>0 & woodp>0;
replace a=. if w_trips_==-4 | w_trips_==-1;
gen b=0;
replace b=w_trips1 if w_trips1>0 & woodp>0;
replace b=. if w_trips1==-4 | w_trips1==-1;
gen c=0;
replace c=w_trips2 if w_trips2>0 & woodp>0;
replace c=. if w_trips2==-4 | w_trips2==-1;

gen woodtrip= a+b+c;
drop a b c;

** See how many missing
;
count if woodp>0 & (woodt==0 | woodt==.);
count if woodt>0 & woodp==0;

gen tripp=woodt/woodp;
sum tripp if tripp>0, det;

** Since the Median is 2 trips per person per week
   use it for the 17 missing values
;
replace woodt=2*woodp if woodp>0 & (woodt==0 | woodt==.);
tab woodt;

**  Get the calculations now
;
gen mximpwd=0;
lab var mximpwd "Wood Collection Imp. Exp.";
replace mximpwd=4.3*2*woodt;
sum mximpwd, det;
sum mximpwd if mx>0, det;

list if mximp> 200;
list if tripp>10 & tripp~=.;
keep hhid mximpw;
sort hhid;
save stpwood,replace;

use hhexp06;
merge hhid using stpwood;
drop _merge;
replace mximpw=0 if mximpw==.;
replace mxtutil=mxtutil+mximpw if mximpw>0;

**___________END of WOOD COLLECTION  ADJUSTMENT    **;

sort hhid;
save hhexp06,replace;

**________________File clean up **
;
!del step00.dta;
!del step01.dta;
!del stexp60.dta;
!del stexp61.dta;
!del stexp62.dta;
!del stpwood;
log close;
