#delimit ;

log using do\calexp07,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP07.DO              V : 01              *;
*    Date    : JULY 21, 1994                                *;
*    Infile  : HHFEXP,                                      *;
*    Outfile : HHEXP07                                      *;
*                                                           *;
*    OBJECTIVE: Calculate total Household monthly           *; 
*               expenditure for commodities groups          *;
*                                                           *;
*************************************************************;

set more 1;

use hhfexp;
des;

*_NOTE: There are 160 households that do not report any food          **
        expenditure.  They are left as missing. They can be screened  **
        later using the marker07                                      **
;
** Calculate the Total Montly Expenditure from the shares
;
gen mxgrain = sxgrain*hhtfexp/100;
gen mxmeafi = sxmeafi*hhtfexp/100;
gen mxdairy = sxdairy*hhtfexp/100;
gen mxfruve = sxfruve*hhtfexp/100;
gen mxoils  = sxoils* hhtfexp/100;
gen mxsugar = sxsugar*hhtfexp/100;
gen mxmeals = sxmeals*hhtfexp/100;
gen mxofood = sxother*hhtfexp/100;
gen mxtfood = hhtfexp;

lab data "Month Food expenditure";
lab var mxgrain "Monthly grain month exp.";
lab var mxmeafi "Monthly meat & fish month exp.";
lab var mxdairy "Monthly dairy month exp.";
lab var mxfruve "Monthly fru. and veg. month exp.";
lab var mxoils  "Monthly oil month exp.";
lab var mxsugar "Monthly sugar month exp.";
lab var mxmeals "Monthly meals month exp.";
lab var mxofood "Monthly other month exp.";
lab var mxtfood "Total Monthly Food exp.";

keep hhid mx*;
gen int marker07=1;
lab var marker07 "Marker";
replace marker07=0 if mxtfood==.;
lab def mark 0 "Miss"
             1 "Orig"
             2 "Impute";
lab val marker mark;

** Set all individual commodities to zero if missing     **
** But leave the total food expenditure as missing       **
;
replace mxgrain = 0 if marker07==0;
replace mxmeafi = 0 if marker07==0;
replace mxdairy = 0 if marker07==0;
replace mxfruve = 0 if marker07==0;
replace mxoils  = 0 if marker07==0;
replace mxsugar = 0 if marker07==0;
replace mxmeals = 0 if marker07==0;
replace mxofood = 0 if marker07==0;

sort hhid;
save hhexp07,replace;

des;
sum;

log close;
