#delimit ;

log using do\clcexp08,replace;
set log linesize 200;

*************************************************************;
*                                                           *;
*    Name    : CLCEXP08.DO              V : 01              *;
*    Date    : AUGUST 5, 1994                               *;
*    Infile  : M2_NFS1                                      *;
*    Outfile : HHEXP08                                      *;
*                                                           *;
*    OBJECTIVE: Calculate the total values of actual        *;
*               non food monthly expenditure                *;
*                                                           *;
*************************************************************;
set more 1;
;
clear;
set maxobs 45000;
use m2_nfs1;
des;
sum;

***  CHECK THE MISSING OF THE NON FOOD REGULAR EXPENDITURES  **;

gen flag=1 if rnfs_a<0;
replace rnfs_a=. if flag==1;
tab rnfs_c, sum(flag);
save step08,replace;

*_NOTE: There are several true missing (Do not Know and refusals) values 
        which are set to missing.  Non reporting exenditure is set to 
        zero.  There are in total approximately 64 households that do not
        report any expenditure: they are set to zero
;

** FILL IN THE MISSING VALUES for the net values that was refused or                      
   "Do not know" with medians by cluster and race
;
sort hhid;
merge hhid using strata2;
tab _merge;
drop if _merge~=3;
drop _merge;
gen clustnum=int(hhid/1000);

save stexp80,replace;

**  Collapse individual item by Occupation and Race;

egen medval=median(rnfs_a), by(rnfs_c clust race); 
collapse medval flag, 
max      (medval  . ) 
sum      ( . missobs) 
by       (rnfs_c clust race); 

format medval %9.1f;
sort rnfs_c clust race;
des;

tab rnfs_c if missobs==0, sum(medval);
tab rnfs_c if missobs==1, sum(medval);

des;
save stexp81,replace;

** Put the values back into the file  **
;
use stexp80;
sort rnfs_c clust race;
merge rnfs_c clust race using stexp81;
tab _merge ;
drop _merge;

keep hhid rnfs_c medval;
sort hhid rnfs_c;
save stexp82,replace;

use step08;
sort hhid rnfs_c;
merge hhid rnfs_c using stexp82;
tab _merge;
drop _merge;

gen flag1=1 if flag==1 & medval>=0 & medval~=.; * Flag Replaced value *;
gen flag2=1 if flag==1 & flag1~=1;              * Flag Still missing values *;
replace rnfs_a=medval if flag==1 & medval>=0   ;     

** After looking at the approximately 20 values still missing it
   emerged that in most cases all other households did nor consume that
   item.  It is very reasonable to set them to Zero
;
tab rnfs_c if flag2==1;                        * Table of still Missing *;

replace flag1=1 if flag==1 & rnfs_a==.;
replace flag2=. if flag==1 & rnfs_a==.;        * Reset Still missing values *;
replace rnfs_a=0 if flag==1 & rnfs_a==.;


tab flag ;
tab flag1;
tab flag2;
sort hhid; 

tab rnfs_c if flag==0, sum(rnfs_a);    ** Original Values  **;
tab rnfs_c if flag1==1, sum(rnfs_a);   ** Replaced Values  **;
tab rnfs_c if flag2~=1, sum(rnfs_a);   ** All Values       **;

save step08,replace;

*_________________END of the missing value section  **
;

***  SET UP THE FILE   **
;
use s4_hdef;
keep hhid;
sort hhid;
lab data "Non Food Regular: Mon Expenditure";
save hhexp08,replace;


***  CALCULATE THE INDIVIDUAL EXPENDITURE VARIABLES  ***
;
** comm01;
use step08;
drop if rnfs_c~=1;
collapse rnfs_a flag2, by(hhid) sum(mxcig f2);
recast float mxcig;
lab var mxcig "Cigarettes and Tobacco Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxcig=0 if mxcig==.;
replace mxcig=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;


** comm02;
use step08;
drop if rnfs_c~=2;
collapse rnfs_a flag2, by(hhid) sum(mxalc f2);
recast float mxalc;
lab var mxalc "Spirits Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxalc=0 if mxalc==.;
replace mxalc=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

** comm03;
use step08;
drop if rnfs_c~=3;
collapse rnfs_a flag2, by(hhid) sum(mxent f2);
recast float mxent;
lab var mxent "Entertainment Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxent=0 if mxent==.;
replace mxent=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

** comm04;
use step08;
drop if rnfs_c~=4;
collapse rnfs_a flag2, by(hhid) sum(mxpcare f2);
recast float mxpcare;
lab var mxpcare "Personal Care Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxpcare=0 if mxpcare==.;
replace mxpcare=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

** comm05;
use step08;
drop if rnfs_c~=5;
collapse rnfs_a flag2, by(hhid) sum(mxnews f2);
recast float mxnews;
lab var mxnews "Newspapers Etc. Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxnews=0 if mxnews==.;
replace mxnews=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

** comm06;
use step08;
drop if rnfs_c~=6;
collapse rnfs_a flag2, by(hhid) sum(mxtel f2);
recast float mxtel;
lab var mxtel "Telephone Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxtel=0 if mxtel==.;
replace mxtel=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

** comm07;
use step08;
drop if rnfs_c~=7;
collapse rnfs_a flag2, by(hhid) sum(mxcar f2);
recast float mxcar;
lab var mxcar "Vehicle Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxcar=0 if mxcar==.;
replace mxcar=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

** comm08;
use step08;
drop if rnfs_c~=8;
collapse rnfs_a flag2, by(hhid) sum(mxtran f2);
recast float mxtran;
lab var mxtran "Transportation Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxtran=0 if mxtran==.;
replace mxtran=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

** comm09;
use step08;
drop if rnfs_c~=9;
collapse rnfs_a flag2, by(hhid) sum(mxwash f2);
recast float mxwash;
lab var mxwash "Washing Supplies Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxwash=0 if mxwash==.;
replace mxwash=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

** comm10;
use step08;
drop if rnfs_c~=10;
collapse rnfs_a flag2, by(hhid) sum(mxchil f2);
recast float mxchil;
lab var mxchil "Day Care Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxchil=0 if mxchil==.;
replace mxchil=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

** comm11;
use step08;
drop if rnfs_c~=11;
collapse rnfs_a flag2, by(hhid) sum(mxdues f2);
recast float mxdues;
lab var mxdues "Dues Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxdues=0 if mxdues==.;
replace mxdues=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

** comm12;
use step08;
drop if rnfs_c~=12;
collapse rnfs_a flag2, by(hhid) sum(mxdon f2);
recast float mxdon;
lab var mxdon "Donations Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxdon=0 if mxdon==.;
replace mxdon=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

** comm13;
use step08;
drop if rnfs_c~=13;
collapse rnfs_a flag2, by(hhid) sum(mxhelp f2);
recast float mxhelp;
lab var mxhelp "Household Help Exp.";
save step01,replace;

use hhexp08;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxhelp=0 if mxhelp==.;
replace mxhelp=. if f2==1 ;
drop f2;
sort hhid;
save hhexp08,replace;

      
***  CALCULATE THE TOTAL EXPENDITURES FOR UTILITIES **;

** commTOT;
use step08;
collapse rnfs_a flag flag1 flag2, by(hhid) sum(mxtnf1 flag flag1 flag2);

recast float mxtnf1; 
recast int flag*;
lab var mxtnf1 "Tot reg non food expenditure";
lab var flag  "With Original Missing Values";
lab var flag1 "With Replaced Missing Values";
lab var flag2 "With Values Still Missing";
save step01,replace;

use hhexp08;
sort hhid;
merge hhid using step01;
tab _merge;
drop _merge;
replace flag=0  if flag==.;
replace flag1=0 if flag1==.;
replace flag2=0 if flag2==.;

replace mxtnf1=0 if mxtnf1==.;
replace mxtnf1=. if flag2>=1 ;

gen int marker08=0;
replace marker=1 if flag==0 ;
replace marker=2 if flag1>=1 & flag2==0 ;

lab var marker "Marker";
lab def mark 0 "Miss"
             1 "Orig"
             2 "Impute";
lab val marker mark;

tab marker08;

drop flag*;
sort hhid;          
save hhexp08,replace;
     
**________________File clean up **
;
!del step08.dta;
!del step01.dta;
!del stexp80.dta;
!del stexp81.dta;
!del stexp82.dta;

log close;
