#delimit ;

log using do\clcexp09,replace;
set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP09.DO              V : 01              *;
*    Date    : AUGUST 5, 1994                               *;
*    Infile  : M2_NFS2                                      *;
*    Outfile : HHEXP09                                      *;
*                                                           *;
*    OBJECTIVE: Calculate the total values of actual        *;
*               Occasional non food expenditure             *;
*                                                           *;
*************************************************************;
set more 1;
;
clear;
set maxobs 45000;
use m3_nfs2;
des;
sum;

***  CHECK THE MISSING OF THE NON FOOD REGULAR EXPENDITURES  **;

gen flag=1 if onfs_a<0;
replace onfs_a=. if flag==1;
tab onfs_c, sum(flag);
save step09,replace;

*_NOTE: There are several true missing (Do not Know and refusals) values 
        which are set to missing.  Non reporting exenditure is set to 
        zero.  There are in total approximately 748 households that do not
        report any expenditure: they are set to zero
;

** FILL IN THE MISSING VALUES for the net values that was refused or                      
   "Do not know" with medians by cluster and race
;
sort hhid;
merge hhid using strata2;
tab _merge;
drop if _merge~=3;
drop _merge;
gen clustnum=int(hhid/1000);

save stexp90,replace;

**  Collapse individual item by Item Cluster and Race;

egen medval=median(onfs_a), by(onfs_c clust race); 
collapse medval flag, 
       max(medval  . ) sum( . missobs) by(onfs_c clust race); 

format medval %9.2f;
sort onfs_c clust race;
des;

tab onfs_c if missobs==0, sum(medval);
tab onfs_c if missobs==1, sum(medval);

des;
save stexp91,replace;

** Put the values back into the file  **
;
use stexp90;
sort onfs_c clust race;
merge onfs_c clust race using stexp91;
tab _merge ;
drop _merge;

keep hhid onfs_c medval;
sort hhid onfs_c;
save stexp92,replace;

use step09;
sort hhid onfs_c;
merge hhid onfs_c using stexp92;
tab _merge;
drop _merge;

gen flag1=1 if flag==1 & medval>=0 & medval~=.; * Flag Replaced value *;
gen flag2=1 if flag==1 & flag1~=1;              * Flag Still missing values *;
replace onfs_a=medval if flag==1 & medval>=0   ;     

** After looking at the approximately 20 values still missing it
   emerged that in most cases all other households in the same cluster
   did not consume that item.  It is very reasonable to set them to Zero
;
tab onfs_c if flag2==1;                        * Table of still Missing *;

replace flag1=1 if flag==1 & onfs_a==.;
replace flag2=. if flag==1 & onfs_a==.;        * Reset Still missing values *;
replace onfs_a=0 if flag==1 & onfs_a==.;


tab flag ;
tab flag1;
tab flag2;
sort hhid; 

tab onfs_c if flag==0, sum(onfs_a);    ** Original Values  **;
tab onfs_c if flag1==1, sum(onfs_a);   ** Replaced Values  **;
tab onfs_c if flag2~=1, sum(onfs_a);   ** All Values       **;

save step09,replace;

*_________________END of the missing value section  **
;

***  SET UP THE FILE   **
;
use s4_hdef;
keep hhid;
sort hhid;
lab data "Non Food Occasional: Mon Expend";
save hhexp09,replace;

***  CALCULATE THE INDIVIDUAL EXPENDITURE VARIABLES  ***
;
** comm01;
use step09;
drop if onfs_c~=1;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxkit=yexp/12;
drop yexp;
lab var mxkit "Kitchen equipments";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxkit=0 if mxkit==.;
replace mxkit=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;


** comm02;
use step09;
drop if onfs_c~=2;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxhom=yexp/12;
drop yexp;
lab var mxhom "Home rep/maint.";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxhom=0 if mxhom==.;
replace mxhom=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;

** comm03;
use step09;
drop if onfs_c~=3;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxbed=yexp/12;
drop yexp;
lab var mxbed "Bedding/Towels etc.";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxbed=0 if mxbed==.;
replace mxbed=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;

** comm04;
use step09;
drop if onfs_c~=4;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxfurn=yexp/12;
drop yexp;
lab var mxfurn "Furniture/Appliance";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxfurn=0 if mxfurn==.;
replace mxfurn=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;

** comm05;
use step09;
drop if onfs_c~=5;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxshoe=yexp/12;
drop yexp;
lab var mxshoe "Shoes";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxshoe=0 if mxshoe==.;
replace mxshoe=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;

** comm06;
use step09;
drop if onfs_c~=6;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxclth=yexp/12;
drop yexp;
lab var mxclth "Clothes";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxclth=0 if mxclth==.;
replace mxclth=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;

** comm07;
use step09;
drop if onfs_c~=7;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxcmat=yexp/12;
drop yexp;
lab var mxcmat "cloth materials.";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxcmat=0 if mxcmat==.;
replace mxcmat=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;

** comm08;
use step09;
drop if onfs_c~=8;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxdoc=yexp/12;
drop yexp;
lab var mxdoc "Dentists/Doctors/Nurses";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxdoc=0 if mxdoc==.;
replace mxdoc=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;

** comm09;
use step09;
drop if onfs_c~=9;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxhfee=yexp/12;
drop yexp;
lab var mxhfee "Hospital Fees";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxhfee=0 if mxhfee==.;
replace mxhfee=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;

** comm10;
use step09;
drop if onfs_c~=10;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxmedsp=yexp/12;
drop yexp;
lab var mxmedsp "Medical Supplies";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxmedsp=0 if mxmedsp==.;
replace mxmedsp=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;

** comm11;
use step09;
drop if onfs_c~=11;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxtrad=yexp/12;
drop yexp;
lab var mxtrad "Traditional Healer";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxtrad=0 if mxtrad==.;
replace mxtrad=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;

** comm12;
use step09;
drop if onfs_c~=12;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxholi=yexp/12;
drop yexp;
lab var mxholi "Holidays";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxholi=0 if mxholi==.;
replace mxholi=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;

** comm13;
use step09;
drop if onfs_c~=13;
collapse onfs_a flag2, by(hhid) sum(yexp f2);
gen float mxlux=yexp/12;
drop yexp;
lab var mxlux "Luxury Goods";
save step01,replace;

use hhexp09;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxlux=0 if mxlux==.;
replace mxlux=. if f2==1 ;
drop f2;
sort hhid;
save hhexp09,replace;


***  CALCULATE THE TOTAL EXPENDITURES FOR UTILITIES **;

** commTOT;
use step09;
collapse onfs_a flag flag1 flag2, by(hhid) sum(yexp flag flag1 flag2);

gen float mxtnf2=yexp/12; 
drop yexp;
recast int flag*;
lab var mxtnf2 "Tot occas. non food expenditure";
lab var flag  "With Original Missing Values";
lab var flag1 "With Replaced Missing Values";
lab var flag2 "With Values Still Missing";
save step01,replace;

use hhexp09;
sort hhid;
merge hhid using step01;
tab _merge;
drop _merge;
replace flag=0  if flag==.;
replace flag1=0 if flag1==.;
replace flag2=0 if flag2==.;

replace mxtnf2=0 if mxtnf2==.;
replace mxtnf2=. if flag2>=1 ;

gen int marker09=0;
replace marker=1 if flag==0 ;
replace marker=2 if flag1>=1 & flag2==0 ;

lab var marker "Marker";
lab def mark 0 "Miss"
             1 "Orig"
             2 "Impute";
lab val marker mark;

tab marker09;

drop flag*;
sort hhid;          
save hhexp09,replace;

        
**________________File clean up **
;
!del step09.dta;
!del step01.dta;
!del stexp90.dta;
!del stexp91.dta;
!del stexp92.dta;

log close;
