#delimit ;

log using do\clcexp14,replace;
set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP14.DO              V : 01              *;
*    Date    : AUGUST 5, 1994                               *;
*    Infile  : M1_ED2, M4_ED1, STRATA                       *;
*    Outfile : HHEXP14                                      *;
*                                                           *;
*    OBJECTIVE: Calculate the values of educational         *;
*               expenditure on a montly basis               *;
*                                                           *;
*************************************************************;
set more 1;
use m1_ed2;
des;
sum;
drop if educ_exp>50;


** CHECK THE MISSING VALUES OF EDUCATIONAL EXPENDITURE  **;

gen flag=1 if educ_ex1<0;
replace educ_ex1=. if flag==1;

tab educ_exp, sum(educ_ex1);
tab educ_exp if flag==1;

replace educ_ex1=educ_ex1/12;   ** Set the monthly variable ;
save step14,replace;


*_NOTE: There are several true missing (414 Don't know/refusals).
        In total there are 5457 households reporting educational
        expenditure and 5362 households that have kids in the education.  
        There are 102 households that have expenditure but no kids in
        school.  All cases of non reporting Educational expenditure 
        are set to zero.
;
** FILL IN THE MISSING VALUES for the values that was refused or                      
   "Do not know" with per student medians by cluster and race
;

** Get the Number of students  **
;
use m4_ed1;
collapse pcode, count(numstu) by(hhid);
save sts1,replace;

use step14;
sort hhid;

merge hhid using sts1;
tab _merge;
drop _merge;
sort hhid;
!del sts1.dta;

merge hhid using strata2;
tab _merge;
drop if _merge~=3;
drop _merge;
gen clustnum=int(hhid/1000);

save stexp140,replace;

**  Collapse individual item by Occupation and Race;

gen pstexp=educ_ex1/numstu;
egen pcmedval=median(pstexp), by(educ_exp clust race); 
collapse pcmedval flag, 
       max(pcmedval  . ) sum( . missobs) by(educ_exp clust race); 

format pcmedval %9.2f;
sort educ_exp clust race;
des;

tab educ_exp if missobs==0, sum(pcmedval);
tab educ_exp if missobs==1, sum(pcmedval);

des;
save stexp141,replace;

** Put the values back into the file  **
;
use stexp140;
sort educ_exp clust race;
merge educ_exp clust race using stexp141;
tab _merge ;
drop _merge;

keep hhid educ_exp pcmedval numstu;
replace numstu=0 if numstu==.;        ** Verified , do not have kids 6-24;
gen medval=pcmedval*numstu;
sort hhid educ_exp;
save stexp142,replace;

use step14;
sort hhid educ_exp;
merge hhid educ_exp using stexp142;
tab _merge;
drop _merge;

gen flag1=1 if flag==1 & medval>=0 & medval~=.;  * Flag Replaced value *;
gen flag2=1 if flag==1 & flag1~=1;               * Flag Still missing values *;
replace educ_ex1=medval if flag==1 & medval>=0   ;     

tab flag ;
tab flag1;
tab flag2;
sort hhid; 

tab educ_exp if flag==0, sum(educ_ex1);    ** Original Values  **;
tab educ_exp if flag1==1, sum(educ_ex1);   ** Replaced Values  **;
tab educ_exp if flag2~=1, sum(educ_ex1);   ** All Values       **;

save step14,replace;


*_________________END of the missing value section  **
;

** SET UP THE FILE   **
;
use s4_hdef;
keep hhid;
sort hhid;
lab data "Educational Expenditure";
save hhexp14,replace;


***  CALCULATE THE INDIVIDUAL EXPENDITURE VARIABLES  **
;
** comm01;
use step14;
drop if educ_exp~=1;
collapse educ_ex1 flag2, by(hhid) sum(mxpre f1);
recast float mxpre;
lab var mxpre "Fees Preschool";
save step01,replace;

use hhexp14;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxpre=0 if mxpre==.;
replace mxpre=. if f1==1; 
drop f1;
sort hhid;
save hhexp14, replace;

** comm02;
use step14;
drop if educ_exp~=2;
collapse educ_ex1 flag2, by(hhid) sum(mxprim f1);
recast float mxprim;
lab var mxprim "Fees Primary school";
save step01,replace;

use hhexp14;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxprim=0 if mxprim==.;
replace mxprim=. if f1==1;
drop f1;
sort hhid;
save hhexp14,replace;

** comm03;
use step14;
drop if educ_exp~=3;
collapse educ_ex1 flag2, by(hhid) sum(mxsec f1);
recast float mxsec;
lab var mxsec "Fees Secondary School";
save step01,replace;

use hhexp14;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxsec=0 if mxsec==.;
replace mxsec=. if f1==1 ;
drop f1;
sort hhid;
save hhexp14,replace;

** comm04;
use step14;
drop if educ_exp~=4;
collapse educ_ex1 flag2, by(hhid) sum(mxtert f1);
recast float mxtert;
lab var mxtert "Fees Tertiary School";
save step01,replace;

use hhexp14;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxtert=0 if mxtert==.;
replace mxtert=. if f1==1 ;
drop f1;
sort hhid;
save hhexp14,replace;

** comm05;
use step14;
drop if educ_exp~=5;
collapse educ_ex1 flag2, by(hhid) sum(mxunif f1);
recast float mxunif;
lab var mxunif "School Uniforms";
save step01,replace;

use hhexp14;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxunif=0 if mxunif==.;
replace mxunif=. if f1==1 ;
drop f1;
sort hhid;
save hhexp14,replace;

** comm06;
use step14;
keep if educ_exp>=6 & educ_exp<=9 | educ_exp>=11 & educ_exp<=14;
collapse educ_ex1 flag2, by(hhid) sum(mxschoth f1);
recast float mxschoth;
lab var mxschoth "Other School Costs";
save step01,replace;

use hhexp14;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxschoth=0 if mxschoth==.;
replace mxschoth=. if f1>=1 & f1~=.;
drop f1;
sort hhid;
save hhexp14,replace;

** comm07;
use step14;
drop if educ_exp~=10;
collapse educ_ex1 flag2, by(hhid) sum(mxboard f1);
recast float mxboard;
lab var mxboard "School Boarding";
save step01,replace;

use hhexp14;
merge hhid using step01;
tab _merge;
drop _merge;
replace mxboard=0 if mxboard==.;
replace mxboard=. if f1==1 ;
drop f1;
sort hhid;
save hhexp14,replace;


***  CALCULATE THE TOTAL EXPENDITURE FOR EDUCATION   **
;
** commTOT;
use step14;
collapse educ_ex1 flag flag1 flag2 numst, by(hhid) 
         sum(mxtot flag flag1 flag2 .) max(numstu . . . );
recast int flag*;
save step01,replace;

use hhexp14;
merge hhid using step01;
tab _merge;
drop _merge;
gen clu=int(hhid/1000);

** Prepare another round of replacing for remaining missing values
;
sum mx*;

gen a=mxpre/nums;
egen meda=median(a), by(clu);
gen medv=meda*num;
replace mxpre=medv if mxpre==. & medv>=0 & medv~=.;
drop a meda medv;

gen a=mxpri/nums;
egen meda=median(a), by(clu);
gen medv=meda*num;
replace mxpri=medv if mxpri==. & medv>=0 & medv~=.;
drop a meda medv;

gen a=mxsec/nums;
egen meda=median(a), by(clu);
gen medv=meda*num;
replace mxsec=medv if mxsec==. & medv>=0 & medv~=.;
drop a meda medv;

gen a=mxter/nums;
egen meda=median(a), by(clu);
gen medv=meda*num;
replace mxter=medv if mxter==. & medv>=0 & medv~=.;
drop a meda medv;

gen a=mxuni/nums;
egen meda=median(a), by(clu);
gen medv=meda*num;
replace mxuni=medv if mxuni==. & medv>=0 & medv~=.;
drop a meda medv;

gen a=mxscho/nums;
egen meda=median(a), by(clu);
gen medv=meda*num;
replace mxscho=medv if mxscho==. & medv>=0 & medv~=.;
drop a meda medv;

gen a=mxboar/nums;
egen meda=median(a), by(clu);
gen medv=meda*num;
replace mxboar=medv if mxboar==. & medv>=0 & medv~=.;
drop a meda medv;

**__________ End of second replacent section **;


gen mxtsch = mxpre + mxprim + mxsec + mxter +
             mxunif + mxscho + mxboar  ;

sum mxt* ;
drop mxtot;

lab var mxtsch "Total School Expenditure";
lab var flag  "With Original Missing Values";
lab var flag1 "With Replaced Missing Values";
lab var flag2 "With Values Still Missing";

replace flag=0  if flag==.;
replace flag1=0 if flag1==.;
replace flag2=0 if flag2==.;

gen int marker14=0;
replace marker=1 if flag==0;
replace marker=2 if flag1>=1 & flag2==0;

replace marker=2 if marker==0 & mxtsch~=.;  *Reset imputed values straight;

lab var marker "Marker";
lab def mark 0 "Miss"
             1 "Orig"
             2 "Impute";
lab val marker mark;

tab marker;
drop flag*;
sort hhid;
save hhexp14,replace;

**____________________File clean up  **
;
!del step14.dta;
!del step01.dta;
!del stexp140.dta;
!del stexp141.dta;
!del stexp142.dta;
log close;
