#delimit ;

log using do\clcexptr,replace;
set log linesize 200;

*************************************************************;
*                                                           *;
*    Name    : CLCEXPTR.DO              V : 01              *;
*    Date    : JULY 29, 1994                                *;
*    Infile  : M4_ED1, M4_TRAN                              *;
*    Outfile : TRSCH1, TRWK1                                *;
*                                                           *;
*    OBJECTIVE: Calculate reported expenditure cost for     *;
*               transportation for school and work          *;
*                                                           *;
*************************************************************;

set more 1;

** TRANSPORT TO AND FROM SCHOOL  **
;
use m4_ed1;
drop if enrol==2;
keep hhid pcode time tran* age;
des;

** CHECK THE MISSING VALUES    **
;
tab trans_c if trans_c<=0;
replace trans_c=. if trans_c<0;
gen flag=1; 
replace flag=0 if trans_c==.;

tab tran_ed1,sum(trans_c);

gen agegroup=.;
replace ageg=1 if age<=17;
replace ageg=2 if age>=18;

tab ageg;
tab tran_ed1 if ageg==1,sum(trans_c);
tab tran_ed1 if ageg==2,sum(trans_c);

** REPLACE MISSING USING MEDIANS BY RACE, PROVINCE, LOCATION, TRANSPORT 
   The children have been divided into two age groups up to 17 and 18 and 
   over.  When available costs are imputed using the first means of 
   transport specified, otherwise the general mean is used.
;
sort hhid;
merge hhid using strata2;
drop if _merge==2;

** If transport is walk or bicycle value is set at 0
;
replace flag=2    if flag==0 & (tran_ed1==4 | tran_ed1==6);
replace trans_c=0 if trans_c==. & (tran_ed1==4 | tran_ed1==6);

** BY PROVINCE, RACE, AGE and TRANSPORT if transport is specifies
* Calculate medians and replace values *
;
egen medtr1=median(trans_c) if (tran_ed1>0 & tran_ed1<=3) |
                              tran_ed1==5 |
                              tran_ed1==7 | 
                              tran_ed1==8, 
                              by(newpr metro race ageg tran_ed1);

tab tran_ed1 if flag==0,sum(medtr1);
replace flag=2    if flag==0 & medtr1~=. ;
replace trans_c=medtr1 if trans_c==. & medtr1~=.;

** BY PROVINCE, RACE, AGE if transport is not specifies
* Calculate medians and replace values *
;
egen medtr2=median(trans_c), by(newpr metro race ageg);

tab tran_ed1 if flag==0,sum(medtr2);
replace flag=2    if flag==0 & medtr2~=. ;
replace trans_c=medtr2 if trans_c==. & medtr2~=.;

**--------END MISSING VALUE SECTION
;
** Create the file  **
;
keep hhid pcode trans_c flag;
gen flag1=1 if flag==2;
collapse trans_c flag flag1, sum(trsch flag flag1) by(hhid);

gen int markert1=1;
lab var marker "Marker";
replace markert1=2 if flag1>=1;
lab def mark 0 "Miss"
             1 "Orig"
             2 "Impute";
lab val marker mark;

keep hhid trsch marker;
lab data "School transport cost";
sort hhid;
des;
sum;
save trsch1,replace;

 
** TRANSPORT TO AND FROM WORK  **
;
use m4_tran;
des;

** CHECK THE MISSING VALUES    **
;
tab tran_c if tran_c<=0;
replace tran_c=. if tran_c<0;
gen flag=1; 
replace flag=0 if tran_c==.;

tab trans_1,sum(tran_c);

** REPLACE MISSING USING MEDIANS BY RACE, PROVINCE, LOCATION, TRANSPORT 
   When available costs are imputed using the first means of 
   transport specified, otherwise the general mean is used.
;
sort hhid;
merge hhid using strata2;
drop if _merge==2;
replace race=4 if race==5;

** If transport is walk or bicycle value is set at 0
;
replace flag=2    if flag==0 & (trans_1==4 | trans_1==6);
replace tran_c=0 if tran_c==. & (trans_1==4 | trans_1==6);

** BY PROVINCE, RACE, AGE and TRANSPORT if transport is specifies
* Calculate medians and replace values *
;
egen medtr1=median(tran_c) if (trans_1>0 & trans_1<=3) |
                              trans_1==5 |
                              trans_1==7 , 
                              by(newpr metro race trans_1);

tab trans_1 if flag==0,sum(medtr1);
replace flag=2    if flag==0 & medtr1~=. ;
replace tran_c=medtr1 if tran_c==. & medtr1~=.;


** BY PROVINCE, RACE, AGE if transport is not specifies
* Calculate medians and replace values *
;
egen medtr2=median(tran_c), by(newpr metro race);

tab trans_1 if flag==0,sum(medtr2);
replace flag=2    if flag==0 & medtr2~=. ;
replace tran_c=medtr2 if tran_c==. & medtr2~=.;

tab flag;
list if flag==0;

**--------END MISSING VALUE SECTION
;
** Create the file  **
;
keep hhid pcode tran_c flag;
gen flag1=1 if flag==2;
collapse tran_c flag flag1, sum(trwork flag flag1) by(hhid);

gen int markert2=1;
lab var marker "Marker";
replace markert2=2 if flag1>=1;
lab def mark 0 "Miss"
             1 "Orig"
             2 "Impute";
lab val marker mark;

keep hhid trwork marker;
lab data "Work transport cost";
sort hhid;
des;
sum;
save trwk1,replace;

** DONE;
log close;



