#delimit ;

log using do\clcfcnee,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCFCNEE.DO              V : 01              *;
*    Date    : JULY 25,1994                                 *;
*    Infile  : FOODEX10, FOCDE1                             *;
*    Outfile : CPNEED, FOODIMPX, CPIMP, FCODE2              *;
*                                                           *;
*    OBJECTIVE: Calculate files that need to be used for    *;
*               the analysis and calculation of cluster     *;
*               prices.                                     *;
*                                                           *;
*************************************************************;
set more 1;
set maxobs 153000;
use foodex10;
des;

**  CALCULATE THE NUMBER OF COMMODITIES THAT NEED PRICES BY CLUSTER **
;
keep hhid foodcode;
gen clustnum=int(hhid/1000);
gen a=1;
collapse a, count(comnum) by(clust food); 
lab data "Food Codes Observed by Clusters";
recast int com;
lab var com "Num. Commodities Observed by Cluster";
order clust food;
sort clust food;
save cpneed,replace;


** CALCULATE IMPLICIT PRICES. In several cases quantities and values 
   have been observed.  Implicit prices are calculated for households, 
   clusters and overall
;

** HOUSEHOLD PRICES  **
;
use foodex10;
keep
  hhid
  foodcode
  eaten_a
  eaten_v
  flag13;

drop if flag==4 | eaten_a==0 & eaten_v==0;
keep if eaten_v>0 & eaten_a>0;

sort foodcode;
merge foodcode using fcode1;
tab _merge;
drop _merge;

gen eaten_p=eaten_v/(eaten_a*conv_k);
lab var eaten_p "Implicit Price";
tab foodcode, sum(eaten_p);

keep hhid food eaten*;
sort hhid foodcode;
lab data "Implicit Household Prices";
save foodimpx,replace;


** CLUSTER PRICES  **
;
gen clustnum=int(hhid/1000);
egen mdprice=median(eaten_p), by(clust foodcode);
collapse mdprice, max(imprice) by(clust foodcode);
lab var imprice "Median Implicit Cluster Price";
order clust food;
sort clust food;
lab data "Implicit Cluster Prices";
save cpimp,replace;


** OVERALL PRICES  **
;
use foodimpx;
egen mdprice=median(eaten_p), by(foodcode);
egen mprice=mean(eaten_p), by(foodcode);
egen stprice=sd(eaten_p), by(foodcode);
egen numons=count(eaten_p) if eaten_p>0, by(foodcode);

collapse mdprice mprice stprice numons,
        max(mdprice mprice stprice nobs) by(foodcode);
lab data "Sample prices";
lab var mprice "Imputed Mean Kg Price";
lab var mdprice "Imputed Median Kg Price";
lab var stprice "Imputed Standard deviation";
lab var nobs "Number of Observations";

format m* %9.2f;
format st %9.2f;
format no %9.0f;
des;

save fprice,replace;

use fcode1;
merge food using fprice;
drop _merge;
sort food;

list, noobs nodisplay;
save fcode2,replace;

log close;
