
#delimit;
log using do\clcfcp01,replace;
set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CLCFCP01.DO              V : 01              *;
*    Date    : AUGUST 3, 1994                               *;
*    Infile  : COMPRIV9,                                    *;
*    Outfile : CFPRI01                                      *;
*                                                           *;
*    OBJECTIVE: Aggregate the price values for the single   *;
*               commodities in prices that correspond to the*;
*               same items in the food file                 *;
*                                                           *;
*************************************************************;
set more 1;

*************************************************************;
***********    FIRST PRICE     ******************************;
*************************************************************;

use compriv9;
des;
sum;

gen int foodcode=0;
gen fpri1=0;


** FOODCODE 1 - Maize  **;
replace foodcode=1 if item==1 | item==2;
egen a=sum(price1) if item<3, by(clust);
egen b=count(price1) if item<3, by(clust);
gen c=a/b;
replace fpri1=c if food==1;
drop a b c;

** FOODCODE 2 - Mealie Meal  **;
replace foodcode=2 if item==3 | item==4;
egen a=sum(price1) if item>=3 & item<=4, by(clust);
egen b=count(price1) if item>=3 & item<=4, by(clust);
gen c=a/b;
replace fpri1=c if food==2;
drop a b c;

** FOODCODE 3  - Rice  **;
replace foodcode=3 if item==5;
gen c=price1;
replace fpri1=c if food==3;
drop c;

** FOODCODE 4  - White, Brown Bread  **;
replace foodcode=4 if item==6 | item==7;
egen a=sum(price1) if item>=6 & item<=7, by(clust);
egen b=count(price1) if item>=6 & item<=7, by(clust);
gen c=(a/b)/.8 ;                   **Convert from loaf to Kg;
replace fpri1=c if food==4;
drop a b c;

** FOODCODE 5  - Wheat Flour  **;
replace foodcode=5 if item==8;
gen c=price1;
replace fpri1=c if food==5;
drop c;

** FOODCODE 6 - Breakfast Cereal  **;
replace foodcode=6 if item==9;
gen c=price1;
replace fpri1=c if food==6;
drop c;

** FOODCODE 7  - Dried Pulses  **;
replace foodcode=7 if item==10 | item==11 | item==12;
egen a=sum(price1) if item>=10 & item<=12, by(clust);
egen b=count(price1) if item>=10 & item<=12, by(clust);
gen c=a/b;
replace fpri1=c if food==7;
drop a b c;

** FOODCODE 8  - Potatoes  **;
replace foodcode=8 if item==13;
gen c=price1;
replace fpri1=c if food==8;
drop c;

** FOODCODE 9  - Tomatoes  **;
replace foodcode=9 if item==41;
gen c=price1;
replace fpri1=c if food==9;
drop c;

** FOODCODE 10  - Madumbe, Sweet Potatoes  **;
replace foodcode=10 if item==14 | item==15;
egen a=sum(price1) if item>=14 & item<=15, by(clust);
egen b=count(price1) if item>=14 & item<=15, by(clust);
gen c=a/b;
replace fpri1=c if food==10;
drop a b c;

** FOODCODE 11 - Vegetable Oil **;
replace foodcode=11 if item==16;
gen c=price1;
replace fpri1=c if food==11;
drop c;

** FOODCODE 12  - Margarine, Butter  **;
replace foodcode=12 if item==17 | item==18;
egen a=sum(price1) if item>=17 & item<=18, by(clust);
egen b=count(price1) if item>=17 & item<=18, by(clust);
gen c=a/b;
replace fpri1=c if food==12;
drop a b c;

** FOODCODE 13  - Cheese  **;
replace foodcode=13 if item==40;
gen c=price1;
replace fpri1=c if food==13;
drop c;

** NONE FOR JAM, FOOD CODE 14 **;

** FOODCODE 15  - Milk, Yoghurt  **;
* weigh fresh milk more (2) *;
replace foodcode=15 if item==19 | item==20 | item==21;
gen a1=price1 if item>=19 & item<=21;
replace a1=price1*2 if item==19;
egen a2=sum(a1) if item>=19 & item<=21, by(clust);
replace a2=. if a2==0;
gen b1=1 if item>=19 & item<=21 & price1~=.;
replace b1=2 if item==19;
egen b2=sum(b1) if item>=19 & item<=21, by(clust);
gen c=(a2/b2); 
replace fpri1=c if food==15;
drop a1 a2 b1 b2 c;

** FOODCODE 16  - Baby Formula, Milk Powder  **;
replace foodcode=16 if item==22 | item==23;
egen a=sum(price1) if item>=22 & item<=23, by(clust);
egen b=count(price1) if item>=22 & item<=23, by(clust);
gen c=a/b;
replace fpri1=c if food==16;
drop a b c;

** FOODCODE 17  - Sugar  **;
replace foodcode=17 if item==24;
gen c=price1;
replace fpri1=c if food==17;
drop c;

** FOODCODE 18  - Mutton, Beef, Pork  **;
replace foodcode=18 if item==25 | item==26 |item==27;
egen a=sum(price1) if item>=25 & item<=27, by(clust);
egen b=count(price1) if item>=25 & item<=27, by(clust);
gen c=a/b;
replace fpri1=c if food==18;
drop a b c;

** FOODCODE 19  - Chicken  **;
replace foodcode=19 if item==28;
gen c=price1;
replace fpri1=c if food==19;
drop c;

** FOODCODE 20  - Eggs  **;
replace foodcode=20 if item==29;
gen c=(price1/12)*16.7;             ** Convert from dozen to Kg ;
replace fpri1=c if food==20;
drop c;

** FOODCODE 21  - Fresh Fish  **;
replace foodcode=21 if item==30;
gen c=price1;
replace fpri1=c if food==21;
drop c;

** FOODCODE 22  - Tinned Fish  **;
replace foodcode=22 if item==31;
gen c=price1/.425;                  ** Convert from Tin to Kg ;
replace fpri1=c if food==22;
drop c;

** FOODCODE 23  - Pumpkin, Squash  **;
replace foodcode=23 if item==32 | item==33;
egen a=sum(price1) if item>=32 & item<=33, by(clust);
egen b=count(price1) if item>=32 & item<=33, by(clust);
gen c=a/b;
replace fpri1=c if food==23;
drop a b c;

** FOODCODE 24  -  Other Vegetables, Carrot/Cabbage  **;
replace foodcode=24 if item==34 | item==35;
egen a=sum(price1) if item>=34 & item<=35, by(clust);
egen b=count(price1) if item>=34 & item<=35, by(clust);
gen c=a/b;
replace fpri1=c if food==24;
drop a b c;

** FOODCODE 25  - Banana  **;
replace foodcode=25 if item==36;
gen c=price1;
replace fpri1=c if food==25;
drop c;

** FOODCODE 26  - Apple  **;
replace foodcode=26 if item==37;
gen c=price1;
replace fpri1=c if food==26;
drop c;

** FOODCODE 27  - Citrus Fruits  **;
replace foodcode=27 if item==38;
gen c=price1;
replace fpri1=c if food==27;
drop c;

** FOODCODE 28  - Soft Drinks  **;
replace foodcode=28 if item==39;
gen c=price1;
replace fpri1=c if food==28;
drop c;


** CODES 29-31 ARE NOT VALID **;


** Collapse the file and create the summary;
collapse fpri1, max(cfpri1) by(clust food);
des;
sum;
save cfpri01,replace;


*************************************************************;
***********   SECOND PRICE     ******************************;
*************************************************************;

use compriv9;
des;
sum;

gen int foodcode=0;
gen fpri2=0;


** FOODCODE 1 - Maize  **;
replace foodcode=1 if item==1 | item==2;
egen a=sum(price2) if item<3, by(clust);
egen b=count(price2) if item<3, by(clust);
gen c=a/b;
replace fpri2=c if food==1;
drop a b c;

** FOODCODE 2 - Mealie Meal  **;
replace foodcode=2 if item==3 | item==4;
egen a=sum(price2) if item>=3 & item<=4, by(clust);
egen b=count(price2) if item>=3 & item<=4, by(clust);
gen c=a/b;
replace fpri2=c if food==2;
drop a b c;

** FOODCODE 3  - Rice  **;
replace foodcode=3 if item==5;
gen c=price2;
replace fpri2=c if food==3;
drop c;

** FOODCODE 4  - White, Brown Bread  **;
replace foodcode=4 if item==6 | item==7;
egen a=sum(price2) if item>=6 & item<=7, by(clust);
egen b=count(price2) if item>=6 & item<=7, by(clust);
gen c=(a/b)/.8 ;                   **Convert from loaf to Kg;
replace fpri2=c if food==4;
drop a b c;

** FOODCODE 5  - Wheat Flour  **;
replace foodcode=5 if item==8;
gen c=price2;
replace fpri2=c if food==5;
drop c;

** FOODCODE 6 - Breakfast Cereal  **;
replace foodcode=6 if item==9;
gen c=price2;
replace fpri2=c if food==6;
drop c;

** FOODCODE 7  - Dried Pulses  **;
replace foodcode=7 if item==10 | item==11 | item==12;
egen a=sum(price2) if item>=10 & item<=12, by(clust);
egen b=count(price2) if item>=10 & item<=12, by(clust);
gen c=a/b;
replace fpri2=c if food==7;
drop a b c;

** FOODCODE 8  - Potatoes  **;
replace foodcode=8 if item==13;
gen c=price2;
replace fpri2=c if food==8;
drop c;

** FOODCODE 9  - Tomatoes  **;
replace foodcode=9 if item==41;
gen c=price2;
replace fpri2=c if food==9;
drop c;

** FOODCODE 10  - Madumbe, Sweet Potatoes  **;
replace foodcode=10 if item==14 | item==15;
egen a=sum(price2) if item>=14 & item<=15, by(clust);
egen b=count(price2) if item>=14 & item<=15, by(clust);
gen c=a/b;
replace fpri2=c if food==10;
drop a b c;

** FOODCODE 11 - Vegetable Oil **;
replace foodcode=11 if item==16;
gen c=price2;
replace fpri2=c if food==11;
drop c;

** FOODCODE 12  - Margarine, Butter  **;
replace foodcode=12 if item==17 | item==18;
egen a=sum(price2) if item>=17 & item<=18, by(clust);
egen b=count(price2) if item>=17 & item<=18, by(clust);
gen c=a/b;
replace fpri2=c if food==12;
drop a b c;

** FOODCODE 13  - Cheese  **;
replace foodcode=13 if item==40;
gen c=price2;
replace fpri2=c if food==13;
drop c;

** NONE FOR JAM, FOOD CODE 14 **;

** FOODCODE 15  - Milk, Yoghurt  **;
* weigh fresh milk more (2) *;
replace foodcode=15 if item==19 | item==20 | item==21;
gen a1=price2 if item>=19 & item<=21;
replace a1=price2*2 if item==19;
egen a2=sum(a1) if item>=19 & item<=21, by(clust);
replace a2=. if a2==0;
gen b1=1 if item>=19 & item<=21 & price2~=.;
replace b1=2 if item==19;
egen b2=sum(b1) if item>=19 & item<=21, by(clust);
gen c=a2/b2; 
replace fpri2=c if food==15;
drop a1 a2 b1 b2 c;

** FOODCODE 16  - Baby Formula, Milk Powder  **;
replace foodcode=16 if item==22 | item==23;
egen a=sum(price2) if item>=22 & item<=23, by(clust);
egen b=count(price2) if item>=22 & item<=23, by(clust);
gen c=a/b;
replace fpri2=c if food==16;
drop a b c;

** FOODCODE 17  - Sugar  **;
replace foodcode=17 if item==24;
gen c=price2;
replace fpri2=c if food==17;
drop c;

** FOODCODE 18  - Mutton, Beef, Pork  **;
replace foodcode=18 if item==25 | item==26 |item==27;
egen a=sum(price2) if item>=25 & item<=27, by(clust);
egen b=count(price2) if item>=25 & item<=27, by(clust);
gen c=a/b;
replace fpri2=c if food==18;
drop a b c;

** FOODCODE 19  - Chicken  **;
replace foodcode=19 if item==28;
gen c=price2;
replace fpri2=c if food==19;
drop c;

** FOODCODE 20  - Eggs  **;
replace foodcode=20 if item==29;
gen c=(price2/12)*16.7;             ** Convert from dozen to Kg ;
replace fpri2=c if food==20;
drop c;

** FOODCODE 21  - Fresh Fish  **;
replace foodcode=21 if item==30;
gen c=price2;
replace fpri2=c if food==21;
drop c;

** FOODCODE 22  - Tinned Fish  **;
replace foodcode=22 if item==31;
gen c=price2/.425;                  ** Convert from Tin to Kg ;
replace fpri2=c if food==22;
drop c;

** FOODCODE 23  - Pumpkin, Squash  **;
replace foodcode=23 if item==32 | item==33;
egen a=sum(price2) if item>=32 & item<=33, by(clust);
egen b=count(price2) if item>=32 & item<=33, by(clust);
gen c=a/b;
replace fpri2=c if food==23;
drop a b c;

** FOODCODE 24  -  Other Vegetables, Carrot/Cabbage  **;
replace foodcode=24 if item==34 | item==35;
egen a=sum(price2) if item>=34 & item<=35, by(clust);
egen b=count(price2) if item>=34 & item<=35, by(clust);
gen c=a/b;
replace fpri2=c if food==24;
drop a b c;

** FOODCODE 25  - Banana  **;
replace foodcode=25 if item==36;
gen c=price2;
replace fpri2=c if food==25;
drop c;

** FOODCODE 26  - Apple  **;
replace foodcode=26 if item==37;
gen c=price2;
replace fpri2=c if food==26;
drop c;

** FOODCODE 27  - Citrus Fruits  **;
replace foodcode=27 if item==38;
gen c=price2;
replace fpri2=c if food==27;
drop c;

** FOODCODE 28  - Soft Drinks  **;
replace foodcode=28 if item==39;
gen c=price2;
replace fpri2=c if food==28;
drop c;


** CODES 29-31 ARE NOT VALID **;


** Collapse the file and create the summary
;
collapse fpri2, max(cfpri2) by(clust food);
des;
sum;
save stcf1,replace;

** Create one file and clean up **
;
use cfpri01;
merge clust food using stcf1;
tab _merge;
drop _merge;
!del stcf1;

drop if food==0;
lab data "Cluster Food Prices";
lab var cfpri1 "Cluster Food Price source 1";
lab var cfpri2 "Cluster Food Price source 2";
do dolabel\label07.do;

des;
sum;

save,replace;

log close;

