#delimit;
log using do\clcfcp03,replace;
set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CLCFCP03.DO              V : 01              *;
*    Date    : JULY 25, 1994                                *;
*    Infile  : CFPRI01, CPNEED, CPIMP                       *;
*    Outfile : CFPRI03                                      *;
*                                                           *;
*    OBJECTIVE: Derive one price from source one and two    *;
*               match with the prices needed for all the    *;
*               commodities that have been reported         *;
*               and fill in the BLANKS                      *;
*                                                           *;
*************************************************************;
set more 1;


** Use the cluster prices and create ONE PRICE FOR EACH COMMODITY. 
   Take the mean of the prices reported from source one and from source two 
;
use cfpri01;
gen cfpri=.;
lab var cfpri "Cluster Food Price";
replace cfpri=(cfpri1+cfpri2)/2 if cfpri1>0 & cfpri2>0 & 
                                   cfpri1~=. & cfpri2~=.; 
replace cfpri=cfpri1 if cfpri1>0 & cfpri2==. & cfpri1~=. ; 
replace cfpri=cfpri2 if cfpri2>0 & cfpri1==. & cfpri2~=. ; 

sort clust food;
save stcp1,replace;


** MATCH WITH THE NEED
;
use cpneed;
merge clust food using stcp1;
drop if food>=29;
tab _merge;

gen flag=0;
replace flag=1 if cfpri==. & comn~=.;
tab flag _merge;
tab food if flag==1;
drop _merge;
sort clust food;
save cfpri03,replace;

** ADD IMPUTED PRICE : From households that report both values & quantities
;
merge clust food using cpimp;
tab _merge;
drop _merge;
sort clust food;

** Replace the price value for Jam with Implicit value - Since no
   Cluster price was collected for that
;
replace flag=0      if food==14 & cfpri==. & impri~=.;
replace cfpri=impri if food==14 & cfpri==. & impri~=.;

save cfpri03,replace;


** REPLACE MISSING USING MAGESTERIAL DISTRICT MEDIANS
;
clear;
set maxobs 100000;
use psample4;
keep clust province md_ncode;
sort clust;
merge clust using metro;
drop _merge;
sort clust;
save stcp2,replace;
use cfpri03;
merge clust using stcp2;
tab _merge;
drop _merge;

* Calculate medians and replace values *
;
egen medmd=median(cfpri) , by(md_ncode food);
tab food, sum(medmd);
tab food if flag==1, sum(medmd);

replace flag=2 if cfpri==. & medmd~=. & com~=.;
replace cfpri=medmd if cfpri==. & medmd~=. & com~=.;

tab food if flag==2, sum(cfpri);

tab food if flag==1;  * How many still Missing ?  *;


** REPLACE REMANINING MISSING WITH PROVINCE AND METRO MEDIANS
;
* Calculate medians and replace values *
;
egen medpm=median(cfpri) , by(province metro food);
tab food, sum(medpm);
tab food if flag==1, sum(medpm);

replace flag=3 if cfpri==. & medpm~=. & com~=.;
replace cfpri=medpm if cfpri==. & medpm~=. & com~=.;

tab food if flag==3, sum(cfpri);

tab food if flag==1;  * How many still Missing ?  *;


** REPLACE REMANINING MISSING WITH PROVINCE MEDIANS
;
* Calculate medians and replace values *
;
egen medp=median(cfpri) , by(province food);
tab food, sum(medp);
tab food if flag==1, sum(medp);

replace flag=4 if cfpri==. & medp~=. & com~=.;
replace cfpri=medp if cfpri==. & medp~=. & com~=.;

tab food if flag==4, sum(cfpri);

tab food if flag==1;  * How many still Missing ?  *;


** REPLACE REMANINING MISSING WITH METRO MEDIANS
;
* Calculate medians and replace values *
;
egen medm=median(cfpri) , by(metro food);
tab food, sum(medm);
tab food if flag==1, sum(medm);

replace flag=5 if cfpri==. & medm~=. & com~=.;
replace cfpri=medm if cfpri==. & medm~=. & com~=.;

tab food if flag==5, sum(cfpri);

tab food if flag==1;  * How many still Missing ?  *;


** REPLACE REMANINING MISSING WITH NATIONAL MEDIANS
;
* Calculate medians and replace values *
;
egen medall=median(cfpri) , by(food);
tab food, sum(medall);
tab food if flag==1, sum(medall);

replace flag=6 if cfpri==. & medall~=. & com~=.;
replace cfpri=medall if cfpri==. & medall~=. & com~=.;

tab food if flag==6, sum(cfpri);

tab food if flag==1;  * How many still Missing ?  *;


**** CLEAN UP  **
;
drop if com==.;
lab var flag "Missing Values";
lab def fl 0 "O.K."
           1 "Miss"
           2 "Clust" 
           3 "Pro/Metro"
           4 "Pro"
           5 "Metro"
           6 "All";
lab val flag fl;
tab flag;

drop med*;
lab data "Needed Cluster Food Prices";
sort clust food ;
save cfpri03,replace;


!del stcp1.dta;
!del stcp2.dta;
log close;
