#delimit ;

log using do\clcinc04,replace;
set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CLCIN04.DO               V : 01              *;
*    Date    : MAY 30,1994                                  *;
*    Infile  : S1_HSV1                                      *;
*    Outfile : HHINC04                                      *;
*                                                           *;
*    OBJECTIVE: Calculate Inputed Housing Income            *;
*                Also adds other rental                     *;
*                                                           *;
*************************************************************;
set more 1;
use s4_hdef;
keep hhid;
sort hhid;

** Get values of rental income from housing     **
;
merge hhid using s4_hsv1;
tab _merge;
sort hhid;

** This calculates a value of imputed income from housing defined as 
   the rental value of housing assets net of bond owed using a 13%  
   return. This is the median from S7.2 (Property File)      *
;
**  NOTE: There are few missing values among people that own the 
          house and have a bond, but do not report the resale
          value of the house nor the value of the bond (about 100,
          House values can easily calculated, but bond values
          cannot be assumed, therefore they are left as missing).
;

gen netvalu=0;
replace netvalu=sale_val-bond_owe if sale_val>0 & bond_owe>=0;
replace netvalu=0 if netvalu<0;
gen imprent=netvalu*.13/12;
sum imprent;

keep hhid imprent;
sort hhid;
save hhinc04,replace;

** Get values of farming rental income from file 18  **;

use s4_land1;
keep hhid rent_rec rent_re1;
gen farmrent=0;
replace farmrent=rent_rec if rent_rec>0 & rent_rec~=.;
gen liverent=0;
replace liverent=rent_re1 if rent_re1>0 & rent_re1~=.;
drop rent_rec rent_re1;
sort hhid;
save temprent,replace;

use hhinc04;
merge hhid using temprent;
tab _merge;
list hhid if _merge==2;
drop _merge;
replace farmrent=0 if farmrent==.;
replace liverent=0 if liverent==.;
sort hhid;
save hhinc04,replace;

!del temprent.dta;

** Get values of rental income from file 19  **;

use m3_land2;
replace rental_v=value*0.13 if rental_v<=0;
gen rentinc=0;
replace rentinc=rental_v/12 if rental_v>0;

sort hhid;
collapse rentinc, sum(rentinc) by (hhid);
sort hhid;
save temprent,replace;

use hhinc04;
merge hhid using temprent;
replace rentinc=0 if rentinc==.;
tab _merge;
list hhid if _merge==2;
drop _merge;
!del temprent.dta;

lab data "Rental Income";

lab var imprent "Imputed Property Streem Value";
lab var rentinc "Rental Income";
lab var farmrent "Crop Rental Income";
lab var liverent "Grazing Rental Income";

sort hhid;
des;
sum imprent rentinc farmrent liverent;
save hhinc04,replace;

log close;
