#delimit ;

log using do\clcinc21,replace;
set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CLCINC21.DO              V : 01              *;
*    Date    : MAY 30, 1994                                 *;
*    Infile  : M3_REMP                                      *;
*    Outfile : INCOME21,HHINC21                             *;
*                                                           *;
*    OBJECTIVE: calculate wage income using file 21         *;
*               Regular wage employment                     *;
*                                                           *;
*************************************************************;
set more 1;

use m6_remp;

**   Calculate necessary variables    *;

gen mnetpay=0;
lab var mnetpay "Monthly net pay";
replace mnetpay=p_netpay      if p_paytyp==3 & p_netpay>0;
replace mnetpay=p_netpay*2.15 if p_paytyp==2 & p_netpay>0;
replace mnetpay=p_netpay*4.3  if p_paytyp==1 & p_netpay>0;

gen mgrspay=0;
lab var mgrspay "Monthly gross pay";
replace mgrspay=p_grossp      if p_paytyp==3 & p_grossp>0;
replace mgrspay=p_grossp*2.15 if p_paytyp==2 & p_grossp>0;
replace mgrspay=p_grossp*4.3  if p_paytyp==1 & p_grossp>0;
sort hhid pcode;
save income21,replace;

** This next step helps get ranges to convert gross to net
    and vice versa if one is missing *;

drop if mnetpay==0 & mgrspay==0;
keep hhid pcode mnetpay mgrspay; 
gen mnetp2=mnetpay if mnetpay~=0;
replace mnetp2=mgrspay*.9 if mnetpay==0;
sort mnetp2;
gen rank=group(4);
tab rank;

sort rank;
save step1,replace;

drop if mnetpay==0 | mgrspay==0;

sort rank;

gen taxratio=mnetpay/mgrspay;
egen ratmed=median(taxratio), by (rank);
tab ratmed;
sort rank;
save step2,replace;
list if hhid==52004;

use step1;
merge rank using step2;
sort hhid pcode;
tab _merge;
drop _merge;
save step3,replace;

use income21;
merge hhid pcode using step3;
tab _merge;
drop _merge;
des;

replace mnetpay=mgrspay*ratmed if mnetpay==0;
replace mgrspay=mnetpay/ratmed if mgrspay==0;
sum mnetpay if mnetpay>0;
sum mgrspay if mgrspay>0;


**      Explore BENEFITS                    *;

gen monthben=0;
lab var monthben "Monthly Benefits";
replace monthben=p_bonus/12 if p_bonus>0 & p_bonus~=.;

gen monthprf=0;
lab var monthprf "Monthly Profit Share";
replace monthprf=p_profit/12 if p_profit>0 & p_profit~=.;

gen monthtvl=0;
lab var monthtvl "Monthly Transport Subsidy";
replace monthtvl=0;
replace monthtvl=subs_t      if p_paytyp==3 & subs_t>0 & subs_t~=.;
replace monthtvl=subs_t*2.15 if p_paytyp==2 & subs_t>0 & subs_t~=.;
replace monthtvl=subs_t*4.3  if p_paytyp==1 & subs_t>0 & subs_t~=.;

gen montheat=0;
lab var montheat "Monthly Food Subsidy";
replace montheat=0;
replace montheat=subs_f      if p_paytyp==3 & subs_f>0 & subs_f~=.;
replace montheat=subs_f*2.15 if p_paytyp==2 & subs_f>0 & subs_f~=.;
replace montheat=subs_f*4.3  if p_paytyp==1 & subs_f>0 & subs_f~=.;

gen mnhouse=0;
lab var mnhouse "Monthly Housing Subsidy";
replace mnhouse=0;
replace mnhouse=subs_h       if p_paytyp==3 & subs_h>0 & subs_h~=.;
replace mnhouse=subs_h*2.15  if p_paytyp==2 & subs_h>0 & subs_h~=.;
replace mnhouse=subs_h*4.3   if p_paytyp==1 & subs_h>0 & subs_h~=.;

!del step1.dta;
!del step2.dta;
!del step3.dta;

**   Create Aggregates  *;

gen nwageinc=mnetpay+monthben+monthprf ;
lab var nwageinc "Net Wage Income"; 

gen gwageinc=mgrspay+monthben+monthprf ;
lab var gwageinc "Gross Wage Income"; 

gen marker =0;

replace marker=1 if mnetpay==. ;
sort hhid pcode;
save income21,replace;
                     

** Fill in the missing values for the net wage that was refused or                      
   Do not know with medians of the hourly wage by occupation and race
;
keep
  hhid pcode    
  k_occ_c  
  k_emplyr 
  k_sector 
  k_hours  
  k_overti 
  p_paytyp 
  nwageinc 
  gwageinc 
  marker   
;

gen hourpay=0;
replace hourpay=nwageinc/(6*k_hours)      if p_paytyp==1 & k_hours>0; 
replace hourpay=nwageinc/(6*k_hours*2.15) if p_paytyp==2 & k_hours>0; 
replace hourpay=nwageinc/(6*k_hours*4.3)  if p_paytyp==3 & k_hours>0; 
sum hourpay if nwageinc>0,det;

sort hhid;
merge hhid using strata2;
tab _merge;
drop if _merge~=3;
drop _merge;

gen marker1=1 if marker==0;

save stinc1,replace;

**  Collapse by Occupation and Race;
des;

egen medhwage=median(hourpay), by(k_occ race); 
collapse medhwage marker marker1, 
       max(medhwage . . ) sum( . missobs haveobs) by(k_occ race); 

format medhwage %9.2f;
sort k_occ race;
save stinc2,replace;

list;

** Put the values back into the file  **
;
use stinc1;
sort k_occ race;
merge k_occ race using stinc2;
tab _merge ;
drop _merge;

gen medwage=0;
replace medwage=medhwage * k_hours * 4.3 * 5; 
sum medwage if medwage>0,det;

keep hhid pcode medwage;

sort hhid pcode;
save stinc3,replace;

use income21;
sort hhid pcode;
merge hhid pcode using stinc3;
tab _merge;
drop _merge;

replace marker=2         if nwageinc==. & medwage>0;
replace nwageinc=medwage if nwageinc==. & medwage>0;
tab marker;

sum nwageinc if marker==0;
sum nwageinc if marker==2;

gen marker21=1 if nwageinc==.;

sort hhid pcode;
save income21,replace;

*______ Calculate Household Totals_________
;

collapse nwageinc gwageinc marker21 monthtvl montheat mnhouse, 
     sum(hhnwage hhgwage marker21 travwage foodwage homewage) by (hhid);

lab data "Wage Income";

lab var hhnwage "Household Net Wage";
lab var hhgwage "Household Gross Wage";
lab var marker21 "Missing Wage value";
lab var travwage "Household Travel Subsidy";
lab var foodwage "Household Food Subsidy";
lab var homewage "Household Housing Subsidy";

des;
sum,det;

save hhinc21,replace;

*____________________DONE;
!del stinc1.dta;
!del stinc2.dta;
!del stinc3.dta;

log close;
