#delimit ;


set log linesize 200;
*************************************************************;
*                                                           *;
*    Name    : CLCINCTM.DO              V : 01              *;
*    Date    : JUNE 10,1994                                 *;
*    Infile  : S2_HDEF,and other income files               *;
*    Outfile : hhinctm                                      *;
*                                                           *;
*    OBJECTIVE: Sum the components of Income                *;
*               Calculate total monthly income              *;
*                                                           *;
*************************************************************;

clear;
set more 1;
use g:\ade\rsadata\dta\s2_hdef;
keep hhid;
sort hhid;

** REMEMBER: Files are not same dimension.  
             After each merge We need to set legimate zeros 
             to that value and some apparent zeros to missing *;


** Bring in RENT INCOME and Imputed Value of Housing             *
   in household level file HHINC04 created using CLCINC04.DO     *
;

merge hhid using hhinc04;
tab _merge;
drop _merge;
replace imprent=0 if imprent==.;
replace rentinc=0 if rentinc==.;
replace farmrent=0 if farmrent==.;
replace liverent=0 if liverent==.;
sort hhid;
lab data "Total Income";
save hhinctm,replace;

** Bring in REMITTANCES                                          *
   in household level file HHINC16 created using CLC16V01.DO     *
;
use hhinc16;
keep hhid totm_cas totm_kin totm_rec;
sort hhid;
save step01,replace;

use hhinctm;
merge hhid using step01;
tab _merge;
drop _merge;
replace totm_rec=0 if totm_rec==.;
replace totm_kin=0 if totm_kin==.;
replace totm_rec=0 if totm_rec==.;
sort hhid;
save hhinctm, replace;


** Bring in REGULAR WAGE INCOME                                  *
   in household level file HHINC21 created using CLCINC21.DO     *
;
merge hhid using hhinc21;
tab _merge;
drop _merge;

replace marker21=0 if marker21==.;
replace hhnwage=0  if hhnwage==.  ;
replace hhnwage=.  if marker21>0  ;
replace hhgwage=0  if hhgwage==.;
replace hhgwage=.  if marker21>0  | hhgwage==0 & marker21>0;

replace travwage=0 if travwage==.;
replace travwage=. if marker21>0 ;

replace foodwage=0 if foodwage==.;
replace foodwage=. if marker21>0;
replace homewage=0 if homewage==.;
replace homewage=. if marker21>0;

sort hhid;
save hhinctm,replace;
clear;

** Bring in FIRST CASUAL INCOME                                  *
   in household level file HHINC22 created using CLCINC22.DO     *
;

bmemsize using hhinctm;
use hhinctm;
merge hhid using hhinc22;
tab _merge;
drop _merge;

replace marker22=0 if marker22==.;
replace hhc1wage=0 if hhc1wage==.;
replace hhc1wage=. if marker22>0;
replace foodcw1=0 if foodcw1==.;
replace foodcw1=. if marker22>0;
replace bencw1=0 if bencw1==.;
replace bencw1=. if marker22>0;

sort hhid;
save hhinctm,replace;


** Bring in SECOND CASUAL INCOME                                 *
   in household level file HHINC23 created using CLCINC23.DO     *
;
merge hhid using hhinc23;
tab _merge;
drop _merge;

replace marker23=0 if marker23==.;
replace hhc2wage=0 if hhc2wage==.;
replace hhc2wage=. if marker23>0;
replace foodcw2=0 if foodcw2==.;
replace foodcw2=. if marker23>0;
replace bencw2=0 if bencw2==.;
replace bencw2=. if marker23>0;

sort hhid;
save hhinctm,replace;


** Bring in AGRICULTURAL INCOME                                  *
   in household level file HHINC25 created using CLCINC25.DO     *
;
merge hhid using hhinc25;
tab _merge;
drop _merge;
replace agincome=0 if agincome==. & largefrm~=1;
replace agsubsid=0 if agsubsid==.;
sort hhid;
save hhinctm,replace;


** Bring in SELF-EMPLOUMENT INCOME                               *
   in household level file HHINC31 created using CLCINC31.DO     *
;
merge hhid using hhinc31;
tab _merge;
drop _merge;

replace marker31=0 if marker31==.;
replace profit31=0 if profit31==.;
replace profit31=. if marker31>0;
sort hhid;
save hhinctm,replace;


** Bring in OTHER TRANSFERS (Ag. Subsidies are Already included) *
   in household level file HHINC32 created using CLCINC32.DO     *
;
merge hhid using hhinc32a;
tab _merge;
drop _merge;

replace marker32=0 if marker32==.;
replace otherinc=0 if otherinc==.;
replace otherinc=. if marker32>0;
sort hhid;
save hhinctm, replace;
**Bring in social pensions**;

bmemsize using hhinc32b;


merge hhid using hhinc32b;
tab _merge;
drop _merge;


replace marker33=0 if marker33==.;
replace socpens=0 if socpens ==.;
replace socpens =. if marker33>0;
sort hhid;

** Take care of extremely long variables - To be done in the single files *
;
recast float _all;
recast long hhid;
recast int mark*;
sort hhid;

save hhinctm,replace;


**   Add VALUE OF FOOD SUPPORT - If needed           **

**   This step is needed to filter cases in which value of wages in
     kind was omitted in the regular wage section, or in the remittances 
     under the mistaken impression that it was doubling counting.
     Uses the file HHFEXPT calculated using CALCXT01.DO
;
merge hhid using hhfexpt;
tab _merge;
drop _merge;

drop tmxpur tmxpro tmxcon;

** Add to the wages for Foood if larger than subsidy and working 
;
replace foodwage=tmxrec if foodwage<tmxrec & totm_kin==0 & 
                           hhnwage>0   & tmxrec~=.               |
                           foodwage==. & totm_kin==0  & tmxrec~=.;

** Add to the remittances if not working and still larger that subsidy
;
replace totm_rec=totm_rec + tmxrec if foodwage<tmxrec & totm_kin==0  &
                                      hhnwage==0 & tmxrec~=.;
sort hhid;
save hhinctm,replace;

** Add HOUSING SUPPORT if needed - See explanation below        **
   
   It is possible that the household does rent the house but does
   not pay any rent.  In that case it is either and underestimation 
   of the value that he receives from the employer, if he is working, or
   from a relative if he is not working
;
use s1_hsv1;
keep hhid rent_mkt ;
keep if rent_mkt>0 & rent_mkt~=.;
sort hhid;
save houstemp,replace;

use hhinctm;
merge hhid using houstemp;
tab _merge;
drop _merge;

** Add to the wages for housing if larger that subsidy and working 
;
replace homewage=rent_mkt if homewage<rent_mkt & hhnwage>0 & rent_mkt~=. |
                             homewage==. & rent_mkt~=. ;

** Add to the remittances if not working and still larger that subsidy
;
replace totm_rec=totm_rec + rent_mkt if hhnwage==0 &
                                        homewage<rent_mkt & rent_mkt~=. ;

!del housetemp;


**   ---------------------- TOTALS ---------------------------   **
**  Add all the pieces together to calculate the total household 
    montly income                                                **
;                        
gen totminc = 
 imprent  + farmrent + liverent + rentinc +
 totm_rec + 
 hhnwage  + travwage + foodwage + homewage + 
 hhc1wage + foodcw1  + bencw1 + 
 hhc2wage + foodcw2  + bencw2 + 
 agincome + agsubsid + 
 otherinc + profit31 + socpens
;
lab var totminc "Total Monthy Income";
sort hhid;
save hhinctm,replace;

sum totminc if totminc>=0,det;

gen tinc_pen=
 imprent  + farmrent + liverent + rentinc +
 totm_rec + 
 hhnwage  + travwage + foodwage + homewage + 
 hhc1wage + foodcw1  + bencw1 + 
 hhc2wage + foodcw2  + bencw2 + 
 agincome + agsubsid =
 otherinc + profit31 ;
lab var totminc "Total Monthy Income";
sort hhid;
save hhinctm,replace;

sum totminc if totminc>=0,det;

*________________________________________________________;


keep    hhid 
        marker*
        imprent farmrent liverent rentinc 
        totm_rec totm_kin
        hhnwage hhgwage travwage homewage foodwage
        hhc1wage foodcw1 bencw1 
        hhc2wage foodcw2 bencw2 
        agincome agsubsid
        otherinc profit31
        totminc socpens tinc_pens;

order   hhid 
        marker*
        imprent farmrent liverent rentinc 
        totm_rec totm_kin
        hhnwage hhgwage travwage homewage foodwage
        hhc1wage foodcw1 bencw1 
        hhc2wage foodcw2 bencw2 
        agincome agsubsid
        otherinc socpens profit31 tinc_pens
        totminc;  

sort hhid;
save hhinctm,replace;


****--------END--------;
log close;


                                           9
