#delimit ;
*************************************************************
*                                                           *
*    Name    : CALCNF2X.DO                V : 02            *
*    Date    : 21 SEP 1999                                  *
*    Infile  : OCCEXP, HHID                                 *
*    Outfile : NF2X02                                       *
*                                                           *
*    OBJECTIVE: Calculate total household monthly           *
*               expenditure for occasional                  *
*               non-food commodities (Section 4.2)          *
*                                                           *
*               Cluster, race, item medians used to impute  *
*               missing values unless otherwise noted       *
*                                                           *
*************************************************************;;

global IN  = "i:\fcn\shared\mp17\safrica\survey98\data\origv2";
global OUT = "i:\fcn\shared\mp17\safrica\survey98\data\consv1";

use $IN\occexp, clear ;

** Merge with HHID to get clustnum and race variables                   **
** Note: 13 Households report nothing (i.e. zero expenditures) here     **;;

merge hhid using $IN\hhid ;
assert _merge==3 | _merge==2 ;
drop _merge ;

** Construct 0/1 flag for missing values                                **;;

gen byte flagocc = ( onfs_a < 0 ) ;

** Calculate cluster & race medians of nonzero purchases                **;;

egen medpval = median(onfs_a) if (onfs_a>0 & onfs_a~=.), 
               by(onfs_c clust race) ;
                
egen medval  = min(medpval),  by(onfs_c clust race) ; 

** List the households and items with missing values and the            **
** corresponding median values for imputations                          **;;

li hhid onfs_c medval if flagocc , noobs nolabel ; 

** Replace missing observations with cluster & race medians             **;;

** Median for cluster 195 with missing rnfs_c=19 is also missing        **
** treat as zero  (short term insurance)                                **;;

** The following program constructs temporary variables to calculate    **
** household level expenditures, replacing missing values with medians  **;;

program define fillmedn ;

 while "`1'"~="" { ;

   gen com`1'     = onfs_a if onfs_c==`1' & flagocc==0 ;
   replace com`1' = medval if onfs_c==`1' & flagocc==1 ;
 
   mac shift         ;
   
   }                 ;

end ;


fillmedn 1 2 3 4  7 8 9 10 11 12 13 14 15 16 17 18 19 21 22 23 ;

                                                    
** Calculate the occasional nonfood expenditures at the household level ** 
** using the temporary variables constructed above                      **
** Note: The "egen & summ" command turns missing values into zeros      **;;

egen yxkit    = sum(com1) , by (hhid) ;
egen yxhom    = sum(com2) , by (hhid) ;
egen yxbed    = sum(com3) , by (hhid) ;
egen yxfurn   = sum(com4) , by (hhid) ;
egen yxadcl   = sum(com22), by (hhid) ;
egen yxkdcl   = sum(com21), by (hhid) ;                  
egen yxcmat   = sum(com7) , by (hhid) ;
egen yxdoc    = sum(com8) , by (hhid) ;
egen yxhfee   = sum(com9) , by (hhid) ;
egen yxmedsp  = sum(com10), by (hhid) ;
egen yxtrad   = sum(com11), by (hhid) ;
egen yxholi   = sum(com12), by (hhid) ;
egen yxlux    = sum(com13), by (hhid) ;    
egen yxcerem  = sum(com23), by (hhid) ;    
egen yxedfee  = sum(com14), by (hhid) ;    
egen yxedbk   = sum(com15), by (hhid) ;  
egen yxedothr = sum(com16), by (hhid) ;   
egen yxins_l  = sum(com17), by (hhid) ;    
egen yxins_m  = sum(com18), by (hhid) ;    
egen yxins_s  = sum(com19), by (hhid) ;   

** Calculate total yearly occasional non-food expenditure for household **;;
  
gen yxtot = yxkit   + yxhom + yxbed + yxfurn + yxadcl + yxkdcl + yxcmat + 
            yxdoc   + yxhfee + yxmedsp + yxtrad + yxholi + yxlux + yxcerem +
            yxedfee + yxedbk + yxedothr + yxins_l + yxins_m + yxins_s ;       

** Label Variables                                                      **;;

label data "1998 Occasional Non-Food Expenditures";

label var yxkit    "98: Year exp: Kitchen equip" ;
label var yxhom    "98: Year exp: Home repair" ;
label var yxbed    "98: Year exp: Bedding/Towels" ;
label var yxfurn   "98: Year exp: Furniture/Appl" ;
label var yxadcl   "98: Year exp: ADULT clothes" ;
label var yxkdcl   "98: Year exp: CHILD clothes" ;
label var yxcmat   "98: Year exp: Material/fabric" ;
label var yxdoc    "98: Year exp: Dentist/Doc/Nurse" ;
label var yxhfee   "98: Year exp: Hospital Fees" ;
label var yxmedsp  "98: Year exp: Medical Supplies" ;
label var yxtrad   "98: Year exp: Traditional Healer" ;
label var yxholi   "98: Year exp: Holidays" ;
label var yxlux    "98: Year exp: Luxury Goods" ;
label var yxcerem  "98: Year exp: Ceremonies" ;
label var yxedfee  "98: Year exp: School fees" ;
label var yxedbk   "98: Year exp: School book/unifrm" ;
label var yxedothr "98: Year exp: Other school" ;
label var yxins_l  "98: Year exp: Insurance -life" ;
label var yxins_m  "98: Year exp: Insurance -medical" ;
label var yxins_s  "98: Year exp: Insurance -term" ;   
label var yxtot    "98: Year exp: Total Occ Non Food" ;
label var flagocc  "98: (1) if any exp item imputed" ; 
     
** Construct household level file, sort to retain non-zero flags        **;;

drop onfs_c onfs_a medval medpval  com* race clustnum ;
gsort + hhid - flag ;
quietly by hhid: keep if _n==1 ;

notes drop _dta ;

order hhid yxkit yxhom yxbed yxfurn yxadcl yxkdcl yxcmat yxdoc yxhfee yxmedsp
 yxtrad yxholi yxlux yxcerem yxedfee yxedbk yxedothr yxins_l yxins_m yxins_s
 yxtot flag ;

sort hhid ;
save $OUT\nf2x02, replace ;         
     
desc ;       
summ ;              

exit;




    


