#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCEXPTL.DO                V : 02            *
*    Date    : 21 SEP 99                                    *
*    Infile  : HHID, HHXHOUS, FOODEXP, NF1X01, NF2X02,      *
*              HHXREM, HHYREG                               *
*    Outfile : EXPEND98                                     *
*                                                           *
*    OBJECTIVE: Calculate total monthly expenditure         *
*                                                           *
*************************************************************;;

global IN ="I:\fcn\shared\mp17\safrica\survey98\data\origv2" ;
global OUT="I:\fcn\shared\mp17\safrica\survey98\data\consv1" ;

use hhid using $IN\hhid ;  
sort hhid;
save $OUT\expend98, replace ;


**----------------------------------------------------------------------**;
** HOUSING EXPENDITURE from HHXHOUS.DTA created by HHYHOUS.DO           **
** Variable mxrent includes rental expenses, imputed rent, & housing    **
** subsidy                                                              **;;
  
use $OUT\hhxhous ;  
keep hhid mxrent flagrent ;
sort hhid ;
merge hhid using $OUT\expend98 ;
assert _merge == 3 ; drop _merge ;
sort hhid;
save $OUT\expend98, replace ;       


**----------------------------------------------------------------------**;

** FOOD EXPENDITURE from FOODEXP.DTA created by FOODEXP.DO              **

** NOTE: Food subsidies reported in employment section (10.2) are       **
**       sometimes larger than those reported consumed from payment (N2)**
**       in Section 3.  This is consistent with not consuming all the   **
**       the in-kind payment of food, that month, so these are not      **
**       included in total food expenditures                            **;;

use $OUT\foodexp ;
keep hhid mxtfood flagfood ;
order mxtfood flagfood ;
sort hhid ;
merge hhid using $OUT\expend98 ;
assert _merge == 3 ; drop _merge;
sort hhid;
save $OUT\expend98,replace;          


**----------------------------------------------------------------------**;

** REGULAR NON FOOD EXPENDITURE from NF1X01.DTA created by CALCNF1X.DO  **;;

use $OUT\nf1x01 ;

** Aggregate some of the regular non-food expenditures                  **;;

gen mxper = mxcig + mxalc + mxent + mxpca + mxnews + mxtel ;

gen mxtransp = mxtran1 + mxcar;

gen mxoth1 = mxwash+mxdues+mxdon+mxhelp ;

label var mxper    "98: Month exp: Personal Items" ;
label var mxtransp "98: Month exp: Transportation & Vehicle ";
label var mxoth1   "98: Month exp: Other Regular Non-Food";

** Verify all expenses are included                                     **;;

gen check = mxper + mxtransp + mxchil + mxoth1 + mxener + mxewr ;
assert check == mxtot ;
                                
keep hhid mxper mxtransp mxchil mxoth1 mxener mxewr flagreg ;

order mxper mxtransp mxchil mxoth1 mxener mxewr flagreg ;
sort hhid ; 
merge hhid using $OUT\expend98 ;
assert _merge == 3 ; drop _merge ;
sort hhid ;

save $OUT\expend98, replace ;    


**----------------------------------------------------------------------**;

** OCCASIONAL NONFOOD EXP from NF2X02.DTA created by CALCNF2X.DO        **;;

use $OUT\nf2x02 ;

** Aggregate some of the occasional non-food expenditures and put on a  **
** monthly basis                                                        **;;

gen mxhous   = ( yxkit   + yxhom   + yxbed    + yxfurn ) / 12 ;
gen mxcloth  = ( yxadcl  + yxkdcl  + yxcmat   )          / 12 ;
gen mxhea    = ( yxdoc   + yxhfee  + yxmedsp  + yxtrad ) / 12 ;
gen mxoth2   = ( yxholi  + yxlux   + yxcerem  )          / 12 ;
gen mxed     = ( yxedf   + yxedb   + yxedothr )          / 12 ;
gen mxinsure = ( yxins_l + yxins_m + yxins_s  )          / 12 ;

** Verify all expenses are included                                     **;;

gen check = mxhous + mxcloth + mxhea + mxoth2 + mxed + mxinsure ;
assert round(check,1) == round( yxtot / 12 , 1) ; 


lab var mxhous   "98: Avg Month exp: HH Items";
lab var mxcloth  "98: Avg Month exp: Clothing";
lab var mxhea    "98: Avg Month exp: Health Care";
lab var mxoth2   "98: Avg Month exp: Other Occassional Non-Food";
lab var mxed     "98: Avg Month exp: Educational";
lab var mxinsure "98: Avg Month exp: Insurance";

keep hhid flagocc mx*;

order mx* flagocc ;
sort hhid;
merge hhid using $OUT\expend98;
assert _merge == 3 ; drop _merge ;
sort hhid;
save $OUT\expend98, replace ;  


**----------------------------------------------------------------------**;

** REMITTANCE EXPENDITURE  from HHXREM.DTA created by CLCXREM.DO        **;;
   
use $OUT\hhxrem ;
keep hhid mxtrem flagrem ;
sort hhid ;
merge hhid using $OUT\expend98 ;
assert _merge == 3 ; drop _merge ;
sort hhid ;
save $OUT\expend98, replace ;           


**----------------------------------------------------------------------**;

** SUBSIDIES from HHYREG.DTA created using CLCYREG.DO                   **
** Transportation subsidies, not yet included in expenses               **;;

** Note: Food subsidies not included for double counting reasons        **
** Note: Housing subsidies already included in mxrent (CLCYHOUS.DO)     **;;

** Combine reported transportation expenses and subsidies               **;;

use $OUT\hhyreg ;                       
keep hhid monthtvl monthhse montheat flaghse ;
sort hhid;
merge hhid using $OUT\expend98 ;
assert _merge == 3 ; drop _merge;
save $OUT\expend98,replace;

** In contrast to the food subsidies, transport subsidies were not
   explicitly asked about in Section 4.1.  Therefore, include here
   The subsidies are retained in the file for researchers who want
   to remove them                                                       **;;
                                                                                              
replace mxtransp = mxtransp + monthtvl ;


** Construct Total Monthly expenditure variable with and without        **
** Remittance expenditures                                              **;;
                                                  
gen totmexp  = mxrent  + mxtfood + mxper + mxtransp + mxoth1 + mxener   +
               mxhous  + mxcloth + mxhea + mxoth2   + mxed   + mxinsure + 
               mxewr   + mxchil;


gen totmexpr = totmexp + mxtrem ; 

label var totmexp  "98: Total Monthly Exp" ;
label var totmexpr "98: Total Monthly Exp w/ remit" ;
label var mxtransp "98: Month exp: Transport w/ subs";

label data "1998 Total Month Expenditure" ;

notes drop _dta ;
                                              
sort hhid;
save $OUT\expend98, replace ;

desc ;
summ ;
summ totmexp , det ;

exit ;



