#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCXREM.DO               V : 02              *
*    Date    : 21 SEP 1999                                  *
*    Infile  : REMSENT, HHID                                *
*    Outfile : HHXREM                                       *
*                                                           *
*    OBJECTIVE: Calculate the total value of remittances    *
*               sent by households (Section 5.2)            *
*                                                           *
*************************************************************;;

global IN  = "I:\fcn\shared\mp17\safrica\survey98\data\origv2";
global OUT = "I:\fcn\shared\mp17\safrica\survey98\data\consv1";

use $IN\remsent, clear ;

** Construct 0/1 flag for missing annual total remittances              **;;

gen byte flagrem = (s_cash_y < 0 | s_inkin1 < 0 ) ;

** List the households with missing annual total expenditures           **
** and corresponding median values for imputations                      **;;

li if flagrem ;

**  Calculate total monthly remittances sent (sum for each household)   **
**  and the number of recipients (COUNT)                                **;;

gen int count = 1 ;

collapse (sum) flagrem s_cash_y s_inkin1 s_cash_m s_inkin2 count, by(hhid) ;

gen float mxremcas = s_cash_y / 12 if s_cash_y ~= . ;
gen float mxremkin = s_inkin1 / 12 if s_inkin1 ~= . ;
gen float mxtrem   = mxremcas + mxremkin ;

recast byte flagrem ;

label data "1998 Remittance Expenditure" ;

label var count    "98: Number of recipients" ;
label var mxremcas "98: Avg Month Remits exp:Cash" ;
label var mxremkin "98: Avg Month Remits exp:Kind" ;
label var mxtrem   "98: Avg Month Remits exp:All" ;
label var s_cash_y "98: Total Year Remits exp:Cash" ;
label var s_cash_m "98: Past Month Remits exp:Cash" ;
label var s_inkin1 "98: Total Year Remits exp:Kind" ;
label var s_inkin2 "98: Past Month Remits exp:Kind" ;
label var flagrem  "98: (1) if missing annual remit" ;

desc ;
summ ;

** NOTE: Fewer than 200 households have remittance expenditure          **

** Now merge with entire household list (HHID) and fill in missing      ** 
** values with zeros                                                    **;

sort hhid;
merge hhid using $IN\hhid ;
assert _merge ~= 1 ; drop _merge ;

** The following program replaces valid missing values with zeros       ** 
** Use flagrem==0 to ensure valid missing values                        **;; 

program define fillzero ;

 while "`1'"~="" { ;
   replace `1'=0 if `1'==. & flagrem==0 ;
   
   mac shift         ;
   
   }                 ;

end ;

replace flagrem=0 if flagrem==. ;

fillzero mxremcas mxremkin mxtrem count s_cash_y s_cash_m s_inkin1 s_inkin2; 

drop race clustnum ;


sort hhid ;
save $OUT\hhxrem, replace ;

desc ;
summ ;

exit ;
