#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCYAGR.DO               V : 03              *
*    Date    : 03 JAN 2000                                  *
*    Infiles : AGPROD, AGTMPWKR, AGPRMWKR, AGINPUT, AGSERV, *
*              AGGRZT, AGANIM, AGSUBS, AGOTHER, HHID        *
*    Outfile : HHYAGR                                       *
*                                                           *
*    OBJECTIVE: Calculate agricultural crop production      *
*               and livestock income and expenditure on     *
*               own production                              *
*                                                           *
*************************************************************;;

global IN   = "i:\fcn\shared\mp17\safrica\survey98\data\origv2" ;
global OUT  = "i:\fcn\shared\mp17\safrica\survey98\data\consv1" ;

***************************************************************
*                                                             *
*  Imputed Income and expenses : agricultural crop production *
*                                                             *
***************************************************************;;

** Agricultural production (AGPROD)                                        **;;

use $IN\agprod ;          
                    
** Keep only those who report a harvest in the past year                   **;;

keep if harvest == 1 ;

** After dropping the non-harvesters, there are 5 observations missing     **
   information for unithrv and/or unitsold - treat as zero and flag        **;;

list if unithrv == -4 | unitsold == -4 ;
gen byte flagagr = ( unithrv == -4 | unitsold == -4 ) ;
replace unithrv = 0 if unithrv == -4 ;
replace unitsold= 0 if unitsold==-4 ;
                                 

** Net unit production after labor and land expenses paid in kind          **;;

gen unity = unithrv - unitlab - unitland ;
tab unity if flagagr == 0 , missing ;   

** Net unit production for own consumption after labor and land expenses   **
   paid in kind and after sales                                            **;;

gen unitcons= unity - unitsold ;
tab unitcons if flagagr == 0, missing;

** There are large variations in avgprice and it may be that total         **
   sales were recorded rather than average price per unit                  **
   Below lists out larger avgprice responses for consideration             **;;

sort crop unit avgprice ;
li hhid crop unithrv unitsold unit avgprice 
   if avgprice > 50 & flagagr == 0 , noobs ;
                                      
** Calculate income net of in-kind payments (agprody) based on unity and   **
** value of crop available for own consumption (ownpro_c) based on unitcon **;;

** The following are imputations for observations where it appears         **
   total income was indicated rather than unit price                       **;;

gen agprody = . ;

replace agprody = 450 if hhid == 2030110 & crop == 1 ;
replace unity   = .   if hhid == 2030110 & crop == 1 ;
replace flagagr = 1   if hhid == 2030110 & crop == 1 ;

tab unity , missing ;

** Convert to standard 1 kg units                                          **;;

gen harvq=0 ;
replace harvq=unity      if unit==1  & unity > 0 ;
replace harvq=unity*10   if unit==2  & unity > 0 ;
replace harvq=unity*25   if unit==3  & unity > 0 ;
replace harvq=unity*50   if unit==4  & unity > 0 ;
replace harvq=unity*80   if unit==5  & unity > 0 ;
replace harvq=unity*1000 if unit==6  & unity > 0 ;
replace harvq=unity*25   if unit==7  & unity > 0 ;
replace harvq=unity*25   if unit==8  & unity > 0 ;
replace harvq=unity*.2   if unit==9  & crop==2  & unity > 0 ;
replace harvq=unity*.25  if unit==9  & crop==5  & unity > 0 ;
replace harvq=unity*1.5  if unit==9  & crop==10 & unity > 0 ;
replace harvq=unity*1.0  if unit==9  & crop~=10 & crop~=2 & crop~=5 & unity>0 ;
replace harvq=unity*10   if unit==10 & unity >0 ;
replace harvq=unity*1    if unit==11 & crop~=7 & unity > 0 ;
replace harvq=unity*10   if unit==11 & crop==7 & unity > 0 ;
replace harvq=unity*20   if unit==13 & unity > 0 ;
replace harvq=unity*10   if unit==15 & unity > 0 ;
replace harvq=unity*5    if unit==16 & unity > 0 ;

tab harvq , missing ;

** Calculate Price per kg                                                  **;;

gen     kgprice = . ;                                      
replace kgprice = avgprice        if unit ==  1 & avgprice > 0 ;
replace kgprice = avgprice / 10   if unit ==  2 & avgprice > 0 ;
replace kgprice = avgprice / 25   if unit ==  3 & avgprice > 0 ;
replace kgprice = avgprice / 50   if unit ==  4 & avgprice > 0 ;
replace kgprice = avgprice / 80   if unit ==  5 & avgprice > 0 ;
replace kgprice = avgprice / 1000 if unit ==  6 & avgprice > 0 ;
replace kgprice = avgprice / 25   if unit ==  7 & avgprice > 0 ;
replace kgprice = avgprice / 25   if unit ==  8 & avgprice > 0 ;
replace kgprice = avgprice / 0.2  if unit ==  9 & avgprice > 0 & crop == 2 ;
replace kgprice = avgprice / 0.25 if unit ==  9 & avgprice > 0 & crop == 5 ;
replace kgprice = avgprice / 1.5  if unit ==  9 & avgprice > 0 & crop ==10 ;
replace kgprice = avgprice        if unit ==  9 & avgprice > 0 &
                                     crop ~=  2 & crop ~=  5   & crop ~=10 ;
replace kgprice = avgprice / 10   if unit == 10 & avgprice > 0 ;
replace kgprice = avgprice        if unit == 11 & avgprice > 0 & crop ==10 ;
replace kgprice = avgprice / 10   if unit == 11 & avgprice > 0 & crop == 7 ;

* Note: do not calculate kgprice for unit=12 (other) *;

replace kgprice = avgprice / 20   if unit == 13 & avgprice > 0;
replace kgprice = avgprice / 10   if unit == 15 & avgprice > 0;
replace kgprice = avgprice / 5    if unit == 16 & avgprice > 0;

tab kgprice , missing ;


** Calculate Median prices per kg price                                    **
** No kg prices for SORGHUM, MILLET, TOMATOES, IMIFIMO, ORCHARD FRUITS     **
** Replace missing price observations with median price by crop            **;;

egen price      = median(kgprice) if ( kgprice > 0 & kgprice ~= . ) , by(crop) ;
egen medprc     = min(price) , by(crop) ;
replace kgprice = medprc if kgprice == . ;

tab kgprice , missing ;


** Calculate total income from agric product, regardless of whether sold   **;;

replace harvq   = 0 if harvq == . ;
replace agprody = harvq * kgprice if ( harvq~=. & kgprice~=. & agprody==. ) ;

** The following observations can be completed although missing kgprice    **;;

li if hhid==2320150 & crop==15 ;
li if hhid==2210060 & crop==21 ;
li if hhid==2160090 & crop==21 ;
li if hhid==2350080 & crop==21 ;

replace agprody = 420 if hhid==2320150 & crop==15 ; * based on other unit *;
replace agprody = 50  if hhid==2210060 & crop==21 ; * based on other unit *;
replace agprody = 50  if hhid==2160090 & crop==21 ; * based on other unit *;
replace agprody = 300 if hhid==2350080 & crop==21 ; * based on other unit *;

tab agprody , missing ;

tab unitcon , missing ;
gen ownpro_c = kgprice * unitcon  if  ( unitcon~=. & kgprice~=. ) ;

replace ownpro_c = 120 if hhid==2320150 & crop==15 ; * based on other unit *;
replace ownpro_c = 30  if hhid==2210060 & crop==21 ; * based on other unit *;
replace ownpro_c = 20  if hhid==2160090 & crop==21 ; * based on other unit *;
replace ownpro_c = 0   if hhid==2350080 & crop==21 ; * based on other unit *;
replace ownpro_c = 0   if hhid==2040040 & crop==2  ; * problem/flagged value *;

tab ownpro_c , missing ;

collapse (sum) ownpro_c agprody (max) flagagr , by(hhid) ;

label var ownpro_c "98: Consumption own crop prdtn" ;
label var agprody  "98: Income own crop prdtn" ;

sort hhid ; save $OUT\hhyagr , replace ;


** Permanent labour costs (AGPRMWKR)                                       **
** This file has only 8 observations                                       **;;

use $IN\agprmwkr ;

** Treat benefits paid as annualised since not specified but says          **
** "all together" indicating for the season                                **;;

gen lcost_p = ( salary * months * numwkr ) + benefits ;
label var lcost_p "98: Perm farm wkr total wage" ;

keep hhid lcost_p ;
sort hhid ; merge hhid using $OUT\hhyagr ;
tab _merge ; drop _merge ;
sort hhid ; save $OUT\hhyagr , replace ;


** Temporary labour costs (AGTMPWKR)                                       **;;

use $IN\agtmpwkr ;

egen med1    = median(wage) if wage > 0 ; 
egen medwage = min(med1) ;
replace wage = medwage if wage < 0 ;

gen lcost_t = ( numwkr * dayswrk * wage ) + meals ;
keep hhid lcost_t ;
collapse (sum) lcost_t , by(hhid) ;
label var lcost_t "98: Temp farm wkr total wage" ;
sort hhid ; merge hhid using $OUT\hhyagr ; 
tab _merge ; drop _merge ;
sort hhid ; save $OUT\hhyagr , replace ;


** Cost of other inputs (AGINPUT)                                          **;;

use $IN\aginput ;

** 8 missing (-4) observations, replace with zero and flag                 **;;

gen flag = ( value < 0 ) ;
replace value = . if value < 0 ;
collapse (sum) value (max) flag , by(hhid) ;

label var value "98: Value of input" ;
sort hhid ; merge hhid using $OUT\hhyagr ;
tab _merge ; drop _merge ;

replace flagagr = 1 if flag == 1 ; drop flag ;

sort hhid ; save $OUT\hhyagr , replace ;


** Land taxes and other farm income (AGSERV)                               **
** Note: no cash rents or in-kind rents recorded                           **
** Note: cash loans not included as these are not income                   **;;

use $IN\agserv ;
gen othfarm = value + letting + providin ;
label var othfarm "98: Other farm income" ;
keep hhid othfarm land ;
sort hhid ; merge hhid using $OUT\hhyagr ;
assert _merge~=1 ; drop _merge ;
sort hhid ; save $OUT\hhyagr , replace ;


** Grazing land fees (AGGRZT)                                              **;;

use $IN\aggrzt ; 
collapse (sum) grazefee , by(hhid) ;
label var grazefee "98: Rent/Grazing fee paid" ;
sort hhid ; merge hhid using $OUT\hhyagr ;
tab _merge ; drop _merge ;
sort hhid ; save $OUT\hhyagr , replace ;

***************************************************************
*                                                             *
*  Imputed Income and expenses : livestock production         *
*                                                             *
***************************************************************;;

** Livestock production                                                    **;;

use $IN\aganim ;

replace sellpric = . if sellpric < 0 ;
egen medsell     = median(sellpric) , by(animcod) ;
replace sellpric = medsell if sellpric == . & animcod ~= 8 ;
replace sellpric = 0 if sellpric == . ; 

replace buyprice = . if buyprice < 0 ;
egen medbuy = median(buyprice) , by(animcod) ;
replace buyprice = medbuy if buyprice == . & anim ~= 8 ;
replace buy      = 0 if animcod == 7 ;
replace buyprice = 0 if animcod == 7 ;
replace buyprice = 0 if animcod == 8 & buy == 0 ;

gen gyanim   = ( sold + slaugh ) * sellpric ;
gen expanim  = ( feedexp + vetexp ) + ( buy * buyp ) ;
gen yanim    = gyanim - expanim  ;

gen ownpro_l = slaugh * sellpric ;
collapse (sum) yanim ownpro_l , by(hhid) ;

label var yanim   "98: Income own lvstk" ;
label var ownpro  "98: Consumption own lvstk" ;

sort hhid ; merge hhid using $OUT\hhyagr ;
tab _merge ; drop _merge ;
sort hhid ; save $OUT\hhyagr , replace ;


** Subsidies (AGSUBS)                                                      **
** Data set has only 3 observations                                        **;;

use $IN\agsubs ; keep hhid valsub ;
replace valsub = . if valsub < 0 ;
sort hhid ; merge hhid using $OUT\hhyagr ;
tab _merge ; drop _merge ;
sort hhid ; save $OUT\hhyagr , replace ;

** Other animal products (AGOTHER)                                         **;;

use $IN\agother;

gen unitexp = avgprod - avglab - avgsell if avgprod > 0 ;

replace estprice = avgprice if estprice == -1 ;

** Impute missing prices using observations on same product and unit       **;;

replace estprice=75 if unit==8  & product==2 & estprice==-4 ;  

tab estprice, missing;

** HH=2341060 has no price or quantity for eggs, set to zero and flag      **;;

replace estprice = . if estprice < 0 ;
replace avgprod  = . if avgprod  < 0 ;
gen flag = ( hhid == 2341060 ) ;

gen othrprod = months * ( avgprod - avglab ) * estprice ;
gen ownpro_o = months * unitexp * estprice ;

collapse (sum) othrprod ownpro_o (max) flag , by(hhid) ;
label var othrprod "98: Income other agric prdtn" ;
label var ownpro_o "98: Consumption own other agric" ;
tab othrprod , missing ;
tab ownpro_o , missing ;
sort hhid ; merge hhid using $OUT\hhyagr ;
tab _merge ; drop _merge ;
replace flagagr=1 if flag==1 ; drop flag ;
sort hhid ; save $OUT\hhyagr , replace ;

** Agricultural rental income - Only one HH reports this                   **;;

use $IN\agserv ;
keep hhid letting ;
rename letting agrent ;
label var agrent "98: Income from letting farmland" ;

sort hhid ; merge hhid using $OUT\hhyagr ;
tab _merge ; drop _merge ;
sort hhid ; save $OUT\hhyagr , replace ;


** Merge with HHID file to complete data set                               **;;

use $IN\hhid ; keep hhid ;
sort hhid ; merge hhid using $OUT\hhyagr ;
tab _merge ; drop _merge ;


** The following program replaces valid missing values with zeros          **;;

program define fillzero ;

 while "`1'"~="" { ;
   replace `1'=0 if `1'==. ; 
   mac shift         ; 
   }                 ;
end ;

fillzero othrprod ownpro_o valsub yanim ownpro_l grazefee land othfarm value
          lcost_t lcost_p  ownpro_c agprody agrent flagagr ;

egen rev = rsum( agprody yanim agrent valsub othfarm othrprod ) ;
tab rev, missing ;

egen exp = rsum( lcost_p lcost_t value land grazefee ) ;
tab exp, missing ;

gen totagric = rev-exp;
drop rev exp ;
gen hhyagr = totagric/12;

label data         "1998 Household Income from Agriculture" ;
label var hhyagr   "98: Net agric monthly Y" ;
label var totagric "98: Net agric annual Y" ;
label var flagagr  "98: (1) Agric msg data dropped" ;

notes drop _dta ;


order hhid agrent othrprod ownpro_o valsub yanim ownpro_l grazefee land othfarm
 value lcost_t lcost_p ownpro_c agprody totagric hhyagr flagagr ;

sort hhid ; save $OUT\hhyagr , replace ;


exit ;
