#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCYHOUS.DO                V : 02            *
*    Date    : 21 SEP 1999                                  *
*    Infile  : HHSERV, HHYREG, HHID                         *
*    Outfile : HHXHOUS, HHYHOUS                             *
*                                                           *
*    OBJECTIVE: Calculate Imputed Housing Income AND        *
*               Housing Expenditure                         *
*                                                           *
*************************************************************;;

global IN ="I:\fcn\shared\mp17\safrica\survey98\data\origv2" ;
global OUT="I:\fcn\shared\mp17\safrica\survey98\data\consv1" ;
   

** IMPORTANT NOTE: Must run CLCYREG.DO before running this program      **
** CLCYREG.DO calculates the value of the housing subsidy/allowance     **
** received (monthhse) which is used in this program                    **;;


use $IN\hhserv, clear ;   

** Merge with HHID to get clustnum and race variables                   **;;

merge hhid using $IN\hhid ;
assert _merge == 3 ; drop _merge ; 


** VERIFY that everyone either owns, rents, lives rent free             **;;

** Owners                                                               **;;

** List those who report owning house but missing or low house value    **;

li hhid ownship_ sale_val bond bond_owe if ownship_==1 & sale_val < 10 ;;


**  NOTE 1: There are 6 missing house values (sale_val) among people 
    ------  that own the house and 2 reporting unbelievably low values.
            Of these, 2 have a bond but do not report the resale value
            and 6 do not have a bond
            
            House values can be imputed, but not bond values
            
            All 8 observations are imputed (and thus the bonds assumed
            to be zero for the two reporting them).                     **;;

** List those who report paying rent but rent amount is missing (Q9b)   **;;

li hhid pay_rent rent_mkt rent_act if pay_rent== 1 & rent_act < 1 ;;

**  NOTE 2: 3 households refused / did not know ACTUAL rent.  Impute    **;;

* List those who report rent-free and not rent amount estimated (Q9c)   **;;

li hhid pay_rentrent_mkt rent_act if pay_rent== 2 & rent_mkt < 1 ;;

**  NOTE 3: 2 households refused / did not know MARKET rent.  Impute    **;;


*-----------------------------------------------------------------------*
* Rent                                                                  *
*-----------------------------------------------------------------------*;;


** Combine market and estimated rent                                    **;;

gen     rentval = rent_act if rent_act > 0;
replace rentval = rent_mkt if rent_mkt > 0;

** Construct cluster & race medians for positive values                 **;;

egen tmprent = median(rentval)  if rentval  > 0, by(clustnum race) ;
egen tmphous = median(sale_val) if sale_val > 0, by(clustnum race) ;

egen medrent = median(tmprent), by(clustnum race) ;
egen medhous = median(tmphous), by(clustnum race) ;
drop tmprent tmphous ;

** Construct flag 0/1/2 to indicate missing values                      **;;

gen     flagrent =      (pay_rent== 1     & rent_act <  1) ;  
replace flagrent =  2 * (pay_rent== 2     & rent_mkt <  1)  if flagrent == 0 ;  
replace flagrent =  3 * (ownship_ == 1 & sale_val < 10)  if flagrent == 0 ; 

li hhid medrent if flagrent == 1 | flagrent == 2 ;
li hhid medhous if flagrent == 3 ;

** Replace missing observations with cluster & race medians             **;;

replace rentval  = medrent if flagrent == 1 ;
replace rentval  = medrent if flagrent == 2 ;
replace sale_val = medhous if flagrent == 3 ;;  

** Household 1930080 is the only HH in cluster that does not own home   **
** Assume a market rent of 13% p.a. of median house value in cluster    **
** (60000 * 0.13 / 12)                                                  **;;


replace rentval = 650 if hhid == 1930080 & rentval==. ;     

** Reset flagrent to 0/1                                                **;;

replace flagrent = 1 if flagrent > 1 ;


*-----------------------------------------------------------------------*
* Imputed Income from owner occupied housing                            *
*-----------------------------------------------------------------------*;;

** Calculate imputed income from housing defined as the rental value    **
** of housing assets net of bond owed using a 13% return.               **
** This is the median from S7.2 (Property File) in Saldru 1993          **
** Note: no corresponding section appears in 1998                       **;;

**  Verify that bond/mortgage outstanding is less than property value   **;;

li hhid ownship_ sale_val bond bond_owe
        if sale_val <= bond_owe & sale_val > 0 & bond_owe ~= . ;;

**  Only 1 case, replace net value with zero to avoid imputed loss      **
**  on housing. Also 1 case where bond and value are equal              **;
                                  
replace bond_owe = 0 if bond == 2 ; * Change from valid missing = -1 *;

gen     netvalu = 0 ;
replace netvalu = sale_val - bond_owe if sale_val > 0 & bond_owe >= 0 ;
replace netvalu = sale_val            if sale_val > 0 & bond_owe <  0  ;
replace netvalu = 0 if netvalu < 0;   

gen     rentimp = netvalu * 0.13/12 ;   
replace rentimp = . if rentval ~= . ;

** Conceptual Issue: While it makes sense to calculate the "income"     **
** from owner occupied housing to be the rate of return on only that    **
** part owned (sale_val - bond_owe) when calculating the expenditure    **
** one should do this on the total value, unless the financing expenses **
** are included elsewhere in the expenditures and they were not asked   **
** about explicitly                                                     **;;

** Therefore, calculate rentimpx on this basis for the expenditure file **;;

gen     rentimpx = sale_val * 0.13/12 ;   
replace rentimpx = . if rentval ~= . ;

sort hhid;
save $OUT\step1, replace;  

** Note: All households now have a value for rentval (actual or market) **
**       or rentimp (imputed from housing value)                        **;;

** Housing subsidies constructed in CLCYREG.DO & stored in HHYREG       **;;

use $OUT\hhyreg , clear ;
keep hhid monthhse ;
sort hhid;               
merge hhid using $OUT\step1 ;
assert _merge == 3 ; drop _merge ;


** NOTE: These calculations are made assuming housing subsidies not     **
**       made in cash. See notes for problems when they are (8 obs)     **;

** There are three cases to consider                                    **;

** (1) Household pays rent and also receives housing subsidy            **
** Add the paid rent and housing subsidy                                **;;

li rentval rent_act monthhse flag     if rent_act > 0 & monthhse > 0  ;

replace rentval = rent_act + monthhse if rent_act > 0 & monthhse > 0 ;


** (2) Household does not pay rent and specified market rent, but       **
** this is lower than housing subsidy received                          **
** Use the value of housing subsidy                                     **;;
   
li rentval rent_mkt monthhse flag if monthhse > rent_mkt & rent_mkt > 0 ;

replace rentval = monthhse        if monthhse > rent_mkt & rent_mkt > 0 ;

** (3) Household owns dwelling and receives subsidy in addition         **
** to imputed rent.  In this case, the subsidy is income and is added   **
** to income in CLCINCTL.DO, but does not affect expenditure on housing **
** So no change made                                                    **;;



*-----------------------------------------------------------------------*
* Housing expenditure (rent or owner occupied imputation)               *
*-----------------------------------------------------------------------*;;

gen     mxrent = rentimpx ;
replace mxrent = rentval if mxrent == . ;

gen byte source = 1 if rent_act ~= -1 ;
replace  source = 2 if rent_mkt ~= -1 ;
replace  source = 3 if source   ==  . ;      

label define source 1"Actual" 2"Market" 3"Owner" ;
label values source source ;

keep hhid rent* flagrent mxrent source ;
sort hhid;

** Label variables                                                      **;;

label data "1998 (Imputed) Housing Expenditure";

label var rentimpx "98: Month exp Impute own-occ rent";
label var rentimp  "98: Month income Impute own-occ rent";
label var rentval  "98: Month exp Impute not-own rent" ;
label var mxrent   "98: Month exp Impute housing";
label var source   "98: Housing/Rent exp source" ;
label var flagrent "98: (1) if rent/hse val imputed" ;

notes drop _dta ;
notes : Calculations assume housing subsidy paid in kind ;

sort hhid ;
save $OUT\hhxhous, replace;     


*-----------------------------------------------------------------------*
* Housing Income (owner occupied imputation)                            *
*-----------------------------------------------------------------------*;;

keep hhid rentimp flagrent ;

rename  flagrent flagval ;
replace flagval = 0 if rentimp == . ;

replace rentimp = 0 if rentimp == . ;

label var flagval "98: (1) if hse val imputed" ;
label data "1998 (Imputed) Income from Housing";


order hhid rentimp flag ;

sort hhid ;
save $OUT\hhyhous, replace;

desc ;
summ ;

use $OUT\hhxhous, clear ;
drop rentimp ;

order hhid rent_act rent_mkt rentval rentimp mxrent source flag ;
sort hhid ;
save $OUT\hhxhous, replace ;

desc ;
summ ;

erase $OUT\step1.dta ;

exit ;


