#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCYNLAB.DO              V : 02              *
*    Date    : 21 SEP 1999                                  *
*    Infile  : NONLABY, HHID                                *
*    Outfile : YNLAB, HHYNLAB                               *
*                                                           *
*    OBJECTIVE: Calculate monthly income from other         *
*               (non-labor) sources (Section 6)             *
*                                                           *
*************************************************************;;

global IN   ="I:\fcn\shared\mp17\safrica\survey98\data\origv2" ;
global OUT  ="I:\fcn\shared\mp17\safrica\survey98\data\consv1" ;

use $IN\nonlaby;

** Exclude packages (source=14) which can be quite large                **;;

drop if source == 14 ;

** Impute value as modal response                                       **;;
                               
replace amt_rec=470 if amt_rec < 0 & source ==  4 ; 
                      
** Construct 0/1 flag for missing values                                **;;

gen byte flagnlab = ( amt_rec < 0 ) ;

replace amt_rec=0 if flagnlab ;

* Construct measures of total, state/govt, and private non-labor income **;;

gen state = amt_rec if source== 1 | source== 4 | source== 6 | source== 8 | source==11 |
                       source==15 | source==16 | source==17 | source==18 ;

gen private = amt_rec if state == . & source~=14 ; 


collapse (sum) nonlaby=amt_rec state private (max) flagnlab, by (hhid pcode);  
assert nonlaby == state + private ;

lab data "1998 Individual Other (Non-labor) Income";

label var state    "HH other income : state";
label var private  "HH other income : private";
label var flagnlab "(1) if missing other income";  
label var nonlaby  "HH other income : total";

notes drop _dta ;

sort hhid pcode ;
save $OUT\ynlab, replace ;     

collapse (sum) nonlaby state private (max) flagnlab, by (hhid);  
assert nonlaby == state + private ; 

** Now merge with entire household list (HHID) and fill in missing      ** 
** values with zeros                                                    **;;

sort hhid ;
merge hhid using $IN\hhid;
assert _merge ~= 1 ;
                                                                                      
** Following program sets valid missing values (after merge) to zero   **;;

program define fillzero ;

 while "`1'"~="" { ;
   replace `1'=0 if `1'==. & _merge==2;
   
   mac shift         ;
   
   }                 ;

end ;

fillzero nonlaby state private flagnlab ; 

drop _merge race clustnum ;    

lab data "1998 HH Other (Non-labor) Income";

label var state    "HH other income : state";
label var private  "HH other income : private";
label var flagnlab "(1) if missing other income";  
label var nonlaby  "HH other income : total";

notes drop _dta ;

order hhid state private nonlaby flag ;

sort hhid ;
save $OUT\hhynlab, replace;

desc ;
summ ;

exit ;
